<?php
/**
 * TGM Init Class
 *
 * @package NEOVANTAGE
 */

if ( file_exists( dirname( __FILE__ ) . '/class-tgm-plugin-activation.php' ) ) {
	require_once get_template_directory() . '/admin/tgm/class-tgm-plugin-activation.php';

	add_action( 'tgmpa_register', 'neovantage_register_plugins' );

	/**
	 * Register the optional plugins for this theme.
	 *
	 * In this, we register four plugins:
	 * - NEOVANTAGE Core included with the TGMPA library
	 * - Redux Framework plugin from the .org repo included with the TGMPA library
	 * - NEO Bootstrap Carousel included with the TGMPA library
	 * - Contact Form 7 included with the TGMPA library
	 * - Instagram Feed included with the TGMPA library
	 *
	 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
	 */
	function neovantage_register_plugins() {
		
		// Get all required and recommended plugins.
		$plugins = neovantage_get_required_and_recommened_plugins();

		$neovantage_config = array(
			'default_path' => '', // Default absolute path to pre-packaged plugins.
			'menu'         => 'neovantage-plugins', // Menu slug.
            'parent_slug'  => 'neovantage', // Menu slug.
            'has_notices'  => true, // If true, admin notices are shown for required/recommended plugins.
			'dismissable'  => true, // If true, admin admin notices can be dismissed by the user.
			'dismiss_msg'  => '', // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => true, // If true, plugins will automatically be activated upon successful installation (for both singular and bulk installation processes).
			'message'      => '<p>NEOVANTAGE Core is our premium plugin recommended to use NEOVANTAGE extended features. The other plugins below offer design integration with NEOVANTAGE. You can manage the plugins from this tab.</p>', // Optional HTML content to include before the plugins table is output. This string will be filtered by wp_kses_post().
            'strings'      => array(
                'page_title'                      => __( 'Install/Update Recommended Plugins', 'neovantage' ),
                'menu_title'                      => __( 'Install Plugins', 'neovantage' ),
                // <snip>...</snip>
                'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
            )
		);
		tgmpa( $plugins, $neovantage_config );
	}
	
	/**
	 * Gets all recommended and required plugins for use in TGM plugin.
	 *
	 * @since 2.0.0
	 */
	function neovantage_get_required_and_recommened_plugins() {
		if ( ! class_exists( 'Neovantage_Importer_Data' ) ) {
			//include_once get_template_directory() . '/includes/importer/class-neovantage-importer-data.php';
		}

		$is_plugins_page = ( isset( $_GET['page'] ) && ( 'neovantage-plugins' === $_GET['page'] || 'install-required-plugins' === $_GET['page'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
		//$plugins_info = get_transient( 'neovantage_premium_plugins_info' );
        $plugins_info = false;
		if ( ! $plugins_info || empty( $plugins_info ) ) {
			$url = 'https://downloads.pixelspress.com/plugins-data.json';

			// Get remote HTML file.
			$response = wp_remote_get( $url, [ 'user-agent' => 'pixelspress-user-agent' ] );

			// Check for error.
			if ( is_wp_error( $response ) ) {
				return [];
			}

			// Parse remote HTML file.
			$data = wp_remote_retrieve_body( $response );

			// Check for error.
			if ( is_wp_error( $data ) ) {
				return [];
			}

			$data = json_decode( $data, true );

			if ( ! is_array( $data ) ) {
				return [];
			}

			$plugins_info = [];
			foreach ( $data as $plugin ) {
				if ( $plugin['premium'] ) {

					// Making sure the correct array index is present, latest_version being returned from server plugin.
					$plugin['version']   = $plugin['latest_version'];
					$plugin['Author']    = $plugin['plugin_author'];
					$plugin['AuthorURI'] = $plugin['plugin_author_url'];
				}

				$plugins_info[ $plugin['slug'] ] = $plugin;
			}

			// Store remote data file in transient, expire after 24 hours.
			set_transient( 'neovantage_premium_plugins_info', $plugins_info, 24 * HOUR_IN_SECONDS );
		}
        
        if ( is_array( $plugins_info ) ) {
			foreach ( $plugins_info as $plugin ) {
				if ( $plugin['has_package'] ) {
                    $plugins_info[ $plugin['slug'] ]['source'] = ( $is_plugins_page ) ? neovantage_get_package( $plugin['name'], $plugin['version'] ) : 'bundled';
				} else {
					$plugins_info[ $plugin['slug'] ]['source'] = 'repo';
				}
			}
		}

		return $plugins_info;
	}
    
    /**
     * Returns the user capability for showing the notices.
     *
     * @return string
     */
    function neovantage_tgm_show_admin_notice_capability() {
        return 'switch_themes';
    }
    add_filter( 'tgmpa_show_admin_notice_capability', 'neovantage_tgm_show_admin_notice_capability' );
}
