<?php
/**
 * Custom comment walker for this theme.
 *
 * @package NEOVANTAGE
 * @since NEOVANTAGE 2.0.0
 */

if ( ! class_exists( 'Neovantage_Walker_Comment' ) ) {
	/**
	 * Custom Comment Walker
	 * A custom walker for comments, based on the walker in Twenty Nineteen.
	 */
	class Neovantage_Walker_Comment extends Walker_Comment {

		/**
		 * Outputs a comment in the HTML5 format.
		 *
		 * @see wp_list_comments()
		 * @see https://developer.wordpress.org/reference/functions/get_comment_author_url/
		 * @see https://developer.wordpress.org/reference/functions/get_comment_author/
		 * @see https://developer.wordpress.org/reference/functions/get_avatar/
		 * @see https://developer.wordpress.org/reference/functions/get_comment_reply_link/
		 * @see https://developer.wordpress.org/reference/functions/get_edit_comment_link/
		 *
		 * @param WP_Comment $comment Comment to display.
		 * @param int        $depth   Depth of the current comment.
		 * @param array      $args    An array of arguments.
		 */
		protected function html5_comment( $comment, $depth, $args ) {

			$tag = ( 'div' === $args['style'] ) ? 'div' : 'li';

			?>
			<<?php echo $tag; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- static output ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( $this->has_children ? 'parent' : '', $comment ); ?>>
				<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
					<?php if ( 0 === $comment->comment_approved ) { ?>
					<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'neovantage' ); ?></p>
					<?php } ?>
					<div class="comment-author vcard">
						<?php
						$comment_author_url = get_comment_author_url( $comment );
						$comment_author     = get_comment_author( $comment );
						$avatar             = get_avatar( $comment, $args['avatar_size'] );
						if ( 0 !== $args['avatar_size'] ) {
							if ( empty( $comment_author_url ) ) {
								echo wp_kses_post( $avatar );
							} else {
								printf( '<a href="%s" rel="external nofollow" class="url">', $comment_author_url ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped --Escaped in https://developer.wordpress.org/reference/functions/get_comment_author_url/
								echo wp_kses_post( $avatar );
							}
						}

						if ( ! empty( $comment_author_url ) ) {
							echo '</a>';
						}
						?>
					</div><!-- .comment-author -->
					<div class="comment-content-area">
						<footer class="comment-meta">
							<?php
							/* translators: %1$s: Author Name. */
							printf( __( '<cite class="comment-author-name">%1$s</cite>', 'neovantage' ), get_comment_author_link() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

							/* translators: %1$s: Comment Published Date. */
							printf( __( '<time class="comment-published">%1$s</time>', 'neovantage' ), get_comment_date( 'F j, Y' ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

							if ( get_edit_comment_link() ) {
								echo ' <span aria-hidden="true">&bull;</span> <a class="comment-edit-link" href="' . esc_url( get_edit_comment_link() ) . '">' . esc_html__( 'Edit', 'neovantage' ) . '</a>';
							}
							?>
						</footer><!-- .comment-meta -->

						<div class="comment-content">
							<?php comment_text(); ?>
						</div><!-- .comment-content -->

						<?php
						$comment_reply_link = get_comment_reply_link(
							array_merge(
								$args,
								array(
									'add_below'  => 'div-comment',
									'reply_text' => '<i class="icon lynny-reply"></i> ' . esc_html__( 'Reply', 'neovantage' ),
									'depth'      => $depth,
									'max_depth'  => $args['max_depth'],
								)
							)
						);

						$by_post_author = neovantage_is_comment_by_post_author( $comment );
						if ( $comment_reply_link || $by_post_author ) {
							?>
						<footer class="comment-footer comment-footer-meta">
							<?php
							if ( $comment_reply_link ) {
								echo $comment_reply_link; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Link is escaped in https://developer.wordpress.org/reference/functions/get_comment_reply_link/
							}
							if ( $by_post_author ) {
								echo '<span class="by-post-author">' . esc_html__( 'By Post Author', 'neovantage' ) . '</span>';
							}
							?>
						</footer>
						<?php } ?>
					</div>
				</article><!-- .comment-body -->
			<?php
		}
	}
}
