<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package NEOVANTAGE
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>
<div id="comments" class="comments-area">
	<?php $comments_number = absint( get_comments_number() ); ?>

	<?php if ( 1 === $comments_number ) { ?>
	<h2 class="comments-title">
		<span><?php esc_html_e( 'One Reply', 'neovantage' ); ?></span>
	</h2>
	<?php } elseif ( $comments_number > 1 ) { ?>
	<h2 class="comments-title">
		<span><?php echo number_format_i18n( $comments_number ) . ' ' . esc_html__( 'Replies', 'neovantage' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
	</h2>
	<?php } ?>

	<?php if ( $comments_number > 0 ) : ?>
	<ol class="comment-list" itemscope="itemscope" itemtype="http://schema.org/UserComments">
	<?php endif; ?>
		<?php
		wp_list_comments(
			array(
				'walker'      => new Neovantage_Walker_Comment(),
				'style'       => 'ol',
				'avatar_size' => 65,
				'short_ping'  => true,
			)
		);
		?>
	<?php if ( $comments_number >= 1 ) : ?>
	</ol><!-- .comment-list -->
	<?php endif; ?>

	<?php
	$comment_pagination = paginate_comments_links(
		array(
			'echo'      => false,
			'end_size'  => 0,
			'mid_size'  => 0,
			'next_text' => __( 'Newer Comments', 'neovantage' ) . ' <span aria-hidden="true">&rarr;</span>',
			'prev_text' => '<span aria-hidden="true">&larr;</span> ' . __( 'Older Comments', 'neovantage' ),
		)
	);
	?>
	<?php
	if ( $comment_pagination ) : // Are there comments to navigate through?
		$pagination_classes = '';

		// If we're only showing the "Next" link, add a class indicating so.
		if ( false === strpos( $comment_pagination, 'prev page-numbers' ) ) {
			$pagination_classes = ' only-next';
		}
		?>
		<nav id="comment-nav-below" class="navigation comment-navigation comments-pagination pagination<?php echo $pagination_classes; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- static output ?>" aria-label="<?php esc_attr_e( 'Comments', 'neovantage' ); ?>" role="navigation">
			<?php echo wp_kses_post( $comment_pagination ); ?>
		</nav><!-- #comment-nav-below -->
	<?php endif; ?>

	<!-- If comments are closed and there are comments, let's leave a little note, shall we? -->
	<?php if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>
	<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'neovantage' ); ?></p>
	<?php endif; ?>

	<?php
	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name__mail' );
	$aria_req  = ( $req ? " aria-required='true'" : '' );
	$args      = array(
		'comment_notes_before' => '',
		'comment_field'        => '<p class="field"><textarea id="comment" name="comment" cols="45" rows="8" class="form-control" required="required" placeholder="' . __( 'Write your comment here.', 'neovantage' ) . '" aria-required="true"></textarea></p>',
		'id_submit'            => 'submit',
		'id_form'              => 'commentform',
		'class_submit'         => 'btn btn-primary',
		'label_submit'         => __( 'Submit', 'neovantage' ),
		'submit_button'        => '<button type="submit" name="%1$s" id="%2$s" class="%3$s">%4$s</button>',
		'fields'               => apply_filters(
			'comment_form_default_fields',
			array(
				'author' =>
				'<p class="comment-form-author">' .
				'<input id="author" name="author" type="text" class="form-control" value="' . esc_attr( $commenter['comment_author'] ) .
				'" size="30"' . $aria_req . ' placeholder="' . __( 'Your full name', 'neovantage' ) . '"></p>',
				'email'  =>
				'<p class="comment-form-email">' .
				'<input id="email" name="email" type="text" class="form-control" value="' . antispambot( $commenter['comment_author_email'] ) .
				'" size="30"' . $aria_req . ' placeholder="' . __( 'E-mail address', 'neovantage' ) . '"></p>',
				'url'    =>
				'<p class="comment-form-url">' .
				'<input id="url" name="url" type="text" class="form-control" value="' . esc_attr( $commenter['comment_author_url'] ) .
				'" size="30" placeholder="' . __( 'Website', 'neovantage' ) . '"></p>',
			)
		),
		'title_reply_before'   => '<h3 id="reply-title" class="comment-reply-title"><span>',
		'title_reply_after'    => '</span></h3>',
	);
	comment_form( $args );
	?>
</div><!-- #comments -->
