<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package NEOVANTAGE
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php wp_head(); ?>
	</head>
	<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
		<?php
		$neovantage_code_body_start = neovantage_get_theme_mod( 'neovantage_code_body_start', false );
		if ( $neovantage_code_body_start ) :
			echo $neovantage_code_body_start; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		endif;
		?>
		<div id="page" class="site">
			<?php /* Preloader */ neovantage_render_preloader(); ?>
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'neovantage' ); ?></a>
			<?php if ( ! is_page_template( 'page-templates/template-landing.php' ) ) : ?>
				<header id="masthead" class="site-header" role="banner"
				<?php if ( get_header_image() ) : ?>
							style="background-image: url(<?php header_image(); ?>);"
						<?php endif; ?>
						>
					<div class="container">
						<div class="flex-row header-height">
							<!-- Logo -->
							<div id="logo" class="flex-col flex-left site-branding">
								<div class="site-logo-wrap">
									<?php
									$custom_logo_id = neovantage_get_theme_mod( 'custom_logo' );
									if ( isset( $custom_logo_id ) && ! empty( $custom_logo_id ) ) {
										neovantage_site_logo();
									} else {
										?>
										<?php if ( is_front_page() && is_home() ) : ?>
											<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><span><?php bloginfo( 'name' ); ?></span></a></h1>
										<?php else : ?>
											<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><span><?php bloginfo( 'name' ); ?></span></a></p>
										<?php endif; ?>
									<?php } ?>
								</div><!-- .site-branding -->
							</div>

							<!-- Center Element -->
							<div  class="flex-col flex-center site-navigation">
								<nav id="site-navigation">
									<?php
									if ( has_nav_menu( 'primary' ) ) {
										wp_nav_menu(
											array(
												'menu'   => 'primary',
												'theme_location' => 'primary',
												'depth'  => 3,
												'container' => false,
												'menu_class' => 'desktop-navigation',
												'walker' => new Neovantage_Walker_Nav_Menu_Main(),
											)
										);
									}
									?>
								</nav>
							</div><!-- #site-navigation -->

							<!-- Right Element -->
							<div class="flex-col flex-right quick-links">
								<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i class="icon lynny-general-menu"></i></button>
							</div>
						</div>
					</div>
				</header><!-- #masthead -->

				<!-- .Mobile Menu -->
				<div class="mobile-navigation-wrapper">
				<?php
				if ( has_nav_menu( 'mobile' ) ) {
					/* Default arguments */
					wp_nav_menu(
						array(
							'theme_location' => 'mobile',
							'menu_id'        => 'mobile',
							'depth'          => 3,
							'container'      => 'nav',
							'menu_class'     => 'mobile-navigation',
							'walker'         => new Neovantage_Walker_Nav_Menu_Mobile(),
						)
					);
				}
				?>
				</div>
			<?php endif; ?>

			<?php get_template_part( 'template-parts/page-header' ); ?>

			<?php
			if ( is_front_page() && is_home() ) {
				$newsticker_id = empty( $atts['custom-id'] ) ? 'newsticker-' . wp_rand() : sanitize_html_class( $atts['custom-id'] );
				?>
			<div class="neovantage-newsticker-wrapper">
				<div class="container">
					<div id="<?php echo esc_attr( $newsticker_id ); ?>" class="neovantage-newsticker" data-speed="<?php echo 1.5 * 3000; ?>">
						<p class="heading"><?php esc_html_e( 'Latest', 'neovantage' ); ?></p>
						<ul class="news-list">
							<?php
							$args = array(
								'posts_per_page' => 10,
								'post_type'      => 'post',
							);

							if ( ! empty( $atts['cat'] ) ) {
								$args['cat'] = $atts['cat'];
							}

							$query = new WP_Query( apply_filters( 'neovantage_news_ticker_query_args', $args ) );

							if ( $query->have_posts() ) {
								while ( $query->have_posts() ) {
									$query->the_post();
									?>
								<li><a class="limit-line" href="<?php the_permalink(); ?>"><?php the_title(); ?></a></li>
									<?php
								}
							} else {
								?>
								<li class="limit-line"> ...</li>
							<?php } ?>
						</ul>
					</div>
				</div>
			</div>
				<?php
				unset( $query );
				unset( $atts );
				unset( $args );
				unset( $newsticker_id );
			}
			?>
		<section id="content" class="site-content">
