<?php
/**
 * Sample implementation of the Custom Header feature.
 *
 * You can add an optional custom header image to header.php like so ...
 *
<?php if ( get_header_image() ) : ?>
<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
</a>
<?php endif; // End header image check. ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package NEOVANTAGE
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses neovantage_header_style()
 */
function neovantage_custom_header_setup() {
	add_theme_support(
		'custom-header',
		apply_filters(
			'neovantage_custom_header_args',
			array(
				'default-image'      => '',
				'default-text-color' => '#ffffff',
				'width'              => 1920,
				'height'             => 700,
				'flex-height'        => false,
				'wp-head-callback'   => 'neovantage_header_style',
			)
		)
	);
}

add_action( 'after_setup_theme', 'neovantage_custom_header_setup' );

if ( ! function_exists( 'neovantage_header_style' ) ) :

	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see neovantage_custom_header_setup().
	 */
	function neovantage_header_style() {
		$header_text_color = get_header_textcolor();
		$theme_color       = neovantage_get_theme_mod( 'neovantage_theme_color' );
		// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">

		<?php if ( ! display_header_text() ) : ?>
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}
			<?php
			// If the user has set a custom color for the text use that.
		else :
			?>
			/*------------------------------------------------------------------
			### Components -> Site Header -> Base
			------------------------------------------------------------------*/
			.site-title a,
			.site-description,
			.site-header .site-branding .site-title a {
				color: #<?php echo esc_attr( $header_text_color ); ?>;
			}
			/*------------------------------------------------------------------
			### Navigation Styles
			------------------------------------------------------------------*/
			.desktop-navigation > li > a,
			.desktop-navigation > li:hover > a,
			.desktop-navigation > li:active > a,
			.desktop-navigation > li:focus > a,
			.menu-toggle {
				color: #<?php echo esc_attr( $header_text_color ); ?>;
			}
			.desktop-navigation li.current-menu-parent.menu-item-has-children > a,
			.desktop-navigation li.current-menu-item > a,
			.desktop-navigation > li:hover > a {
				background: rgba(0, 0, 0, 0.2);
				color: #<?php echo esc_attr( $header_text_color ); ?>;
			}
			.desktop-navigation li .sub-menu li.current-menu-parent.menu-item-has-children > a,
			.desktop-navigation li .sub-menu li.current-menu-item > a,
			.desktop-navigation li .sub-menu li:hover > a {
				background: <?php echo esc_attr( $theme_color ); ?>;
			}
			.desktop-navigation li .sub-menu li .grandchild-menu li.current-menu-item > a,
			.desktop-navigation li .sub-menu li .grandchild-menu li:hover > a {
				background: <?php echo esc_attr( $theme_color ); ?>;
			}
			.mobile-navigation li.current-menu-parent.menu-item-has-children > .container > a,
			.mobile-navigation li.current-menu-item > .container > a,
			.mobile-navigation li a:hover {
				/* color: <?php echo esc_attr( $theme_color ); ?>; */
			}
		<?php endif; ?>
		</style>
		<?php
	}
endif;
