<?php
/**
 * Class to handle Enqueues front-end CSS for Customizer options.
 *
 * @package NEOVANTAGE
 * @author  Mohsin Rafique  <mohsin.rafique@gmail.com>
 */
class Neovantage_Customize_Css {

	public function __construct() {

		// Failsafe is safe.
		add_action( 'wp_enqueue_scripts', array( $this, 'neovantage_customizer_styles' ) );
	}

	/**
	 * Enqueue Customizer styles on the front-end.
	 */
	public function neovantage_customizer_styles() {
		wp_add_inline_style( 'neovantage-style', neovantage_customizer_font_css() );
	}
}
new Neovantage_Customize_Css();

/**
 * Set the Custom Font CSS via Customizer options.
 */
function neovantage_customizer_font_css() {

	$neovantage_heading_font = neovantage_get_theme_mod( 'neovantage_heading_font' );
	$neovantage_body_font    = neovantage_get_theme_mod( 'neovantage_body_font' );

	$font = array(
		1 => neovantage_get_font( 1 ),
		2 => neovantage_get_font( 2 ),
	);

	// Heading fonts.
	$heading_css = '
	h1,
	h2,
	h3,
	h4,
	h5,
	h6,
	.entry-content .header-font:not(.subHeading) {
		' . neovantage_font_css_props( $font[ $neovantage_heading_font ], false ) . '
	}';

	// Body fonts.
	$body_css = '
	body,
	button,
	input,
	select,
	textarea,
	.comments select,
	.comments textarea,
	input[type="search"],
	.comments input[type="url"],
	.comments input[type="text"],
	.comments input[type="email"],
	.wp-block-quote.is-large cite,
	.comments input[type="password"],
	.entry-content .wp-block-coblocks-author__heading,
	.comments #secondary #tucson-optin .tucson-element-tagline-content {
		' . neovantage_font_css_props( $font[ $neovantage_body_font ], false ) . '
	}';

	return strip_tags( $heading_css . $body_css, '"' );
}
