<?php

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 *
 * Action Used in customize_register
 *
 * @since 1.0.0
 */
class Neovantage_Initialise_Customizer_Settings {

	/**
	 * Define the core functionality of the customizer.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		// Failsafe is safe.
		add_action( 'customize_register', array( $this, 'neovantage_failsafe' ) );

		// Register Extented Classes of WP_Customize_Control.
		add_action( 'customize_register', array( $this, 'neovantage_add_custom_controls' ) );

		// Register our Panels.
		add_action( 'customize_register', array( $this, 'neovantage_add_customize_panels' ) );

		// Rearrange our sections.
		add_action( 'customize_register', array( $this, 'neovantage_edit_customize_sections' ) );

		// Register our sections.
		add_action( 'customize_register', array( $this, 'neovantage_add_customize_sections' ) );

		// Register our site identity controls.
		add_action( 'customize_register', array( $this, 'neovantage_get_site_identity_controls' ) );

		// Register our style controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_style_controls' ) );

		// Register our blog controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_single_post_controls' ) );

		// Register our layout controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_layout_controls' ) );

		// Register our footer controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_footer_controls' ) );

		// Register our social media controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_social_media_controls' ) );

		// Register our notice bar & gdpr controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_notice_bar_gdpr_controls' ) );

		// Register our site loader controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_site_loader_controls' ) );

		// Register our maintenance mode controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_maintenance_mode_controls' ) );

		// Register our custom html code controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_custom_html_code_controls' ) );

		// Register our Export/Import code controls.
		add_action( 'customize_register', array( $this, 'neovantage_register_export_import_controls' ) );
	}

	/**
	 * Failsafe is safe
	 *
	 * @param WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 *
	 * @access  public
	 * @version 1.0.0
	 * @since   1.2.6
	 * @return boolean
	 */
	public function neovantage_failsafe( $wp_customize ) {
		if ( ! isset( $wp_customize ) ) {
			return;
		}
	}

	/**
	 * Custom Controls
	 *
	 * @param WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 *
	 * -- Divider Control
	 * -- Switch Control
	 *
	 * @access  public
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_add_custom_controls( $wp_customize ) {
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-customize-divider-control.php';
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-customize-switch-control.php';
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-control-title.php';
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-control-multi-select.php';
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-control-typography.php';
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-control-radio-image.php';
		require_once get_template_directory() . '/inc/customizer/controls/class-neovantage-control-export-import.php';
		$wp_customize->register_control_type( 'Neovantage_Control_Radio_Image' );
	}

	/**
	 * Register the customize panels.
	 *
	 * @param WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 *
	 * @access public
	 * @version 1.0.0
	 * @since 1.2.6
	 */
	public function neovantage_add_customize_panels( $wp_customize ) {

		/**
		 * Header panel
		 *
		 * @since 2.0.0
		 *
		 * @uses $wp_customize->add_panel() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_panel/
		 * @link $wp_customize->add_panel() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_panel
		 */
		$wp_customize->add_panel(
			'header',
			array(
				'priority' => 0,
				'title'    => esc_html__( 'Header', 'neovantage' ),
			)
		);

		/**
		 * Style Panel
		 *
		 * @since   2.0.0
		 *
		 * @uses $wp_customize->add_panel() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_panel/
		 * @link $wp_customize->add_panel() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_panel
		 */
		$wp_customize->add_panel(
			'style',
			array(
				'priority' => 10,
				'title'    => esc_html__( 'Style', 'neovantage' ),
			)
		);

		/**
		 * Blog Panel
		 *
		 * @since   2.0.4
		 *
		 * @uses $wp_customize->add_panel() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_panel/
		 * @link $wp_customize->add_panel() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_panel
		 */
		$wp_customize->add_panel(
			'blog',
			array(
				'priority' => 11,
				'title'    => esc_html__( 'Blog', 'neovantage' ),
			)
		);
	}

	/**
	 * Rearrange Sections
	 *
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 *
	 * @access  public
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_edit_customize_sections( $wp_customize ) {
		$wp_customize->get_section( 'title_tagline' )->panel    = 'header';
		$wp_customize->get_section( 'title_tagline' )->priority = '0';

		$wp_customize->get_section( 'header_image' )->panel    = 'header';
		$wp_customize->get_section( 'header_image' )->priority = '10';

		$wp_customize->get_section( 'colors' )->priority = '0';
		$wp_customize->get_section( 'colors' )->panel    = 'style';

		$wp_customize->get_control( 'background_image' )->section  = 'layout';
		$wp_customize->get_control( 'background_image' )->priority = '50';

		$wp_customize->remove_section( 'background_image' );
	}

	/**
	 * Register the Customize sections
	 *
	 * @param WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @access  public
	 * @since   1.2.6
	 */
	public function neovantage_add_customize_sections( $wp_customize ) {

		/**
		 * Typography Section under 'Style' panel
		 *
		 * @since   2.0.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'typography',
			array( // $args
				'priority'    => 11,
				'panel'       => 'style',
				'title'       => esc_html__( 'Typography', 'neovantage' ),
				'description' => esc_html__( 'Settings related to typography.', 'neovantage' ),
			)
		);

		/**
		 * Footer Section.
		 *
		 * @since   1.2.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'footer',
			array( // $args
				'priority'    => 14,
				'title'       => esc_html__( 'Footer', 'neovantage' ),
				'description' => esc_html__( 'Settings related to footer.', 'neovantage' ),
			)
		);

		/**
		 * Layout.
		 *
		 * @since   1.2.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'layout',
			array( // $args
				'panel' => 'blog',
				'title' => esc_html__( 'Blog Layout', 'neovantage' ),
			)
		);

		/**
		 * Single Post.
		 *
		 * @since 1.2.0
		 * @since 2.0.4 Section name changed from Blog to Post.
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'single-post',
			array( // $args
				'panel'       => 'blog',
				'title'       => esc_html__( 'Single Post', 'neovantage' ),
				'description' => esc_html__( 'Settings related to blog.', 'neovantage' ),
			)
		);

		/**
		 * Social Media
		 *
		 * @since   1.2.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'social-media',
			array( // $args
				'priority'    => 160,
				'title'       => esc_html__( 'Social Media', 'neovantage' ),
				'description' => esc_html__( 'This tab controls the social networks that display in the footer. Add the network of your choice along with your unique URL. Each network you wish to display must be added here to show up in the footer.', 'neovantage' ),
			)
		);

		/**
		 * Notice Bar & GDPR Section
		 *
		 * @version 1.0.0
		 * @since   1.2.6
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'notice-bar-gdpr',
			array(
				'priority' => 180,
				'title'    => esc_html__( 'Notice Bar', 'neovantage' ),
			)
		);

		/**
		 * Site Loader
		 *
		 * @version 1.0.0
		 * @since   2.0.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'site-loader',
			array(
				'priority' => 185,
				'title'    => esc_html__( 'Site Loader', 'neovantage' ),
			)
		);

		/**
		 * Maintenance Mode
		 *
		 * @version 1.0.0
		 * @since   2.0.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'maintenance-mode',
			array(
				'priority' => 190,
				'title'    => esc_html__( 'Maintenance Mode', 'neovantage' ),
			)
		);

		/**
		 * Custom HTML Code
		 *
		 * @since   1.2
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'custom-html-code',
			array(
				'priority' => 210,
				'title'    => esc_html__( 'Custom HTML Code', 'neovantage' ),
			)
		);

		/**
		 * Export/Import
		 *
		 * @since   2.0.0
		 *
		 * @uses    $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
		 * @link    $wp_customize->add_section() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_section
		 */
		$wp_customize->add_section(
			'neovantage-export-import',
			array(
				'title'    => esc_html__( 'Export/Import', 'neovantage' ),
				'priority' => 99999999,
			)
		);
	}

	/**
	 * Get Site Identity controls
	 *
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @access  public
	 * @since   1.2.6
	 */
	public function neovantage_get_site_identity_controls( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	}

	/**
	 * Register our style controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_style_controls( $wp_customize ) {

		/**
		 * Main Theme Color Control.
		 */
		$wp_customize->add_setting(
			'neovantage_theme_color',
			array(
				'default'              => neovantage_get_default_theme_setting( 'neovantage_theme_color' ),
				'sanitize_callback'    => 'neovantage_sanitize_hex_color',
				'sanitize_js_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'neovantage_theme_color',
				array( // $args
					'priority'    => 0,
					'section'     => 'colors',
					'label'       => esc_html__( 'Theme Color', 'neovantage' ),
					'description' => esc_html__( 'Controls the main highlight color throughout the theme.', 'neovantage' ),
				)
			)
		);

		/**
		 * Header Color Control.
		 */
		$wp_customize->add_setting(
			'neovantage_header_bg_color',
			array(
				'default'              => neovantage_get_default_theme_setting( 'neovantage_header_bg_color' ),
				'transport'            => 'postMessage',
				'sanitize_callback'    => 'neovantage_sanitize_hex_color',
				'sanitize_js_callback' => 'maybe_hash_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'neovantage_header_bg_color',
				array(
					'priority'    => 2,
					'section'     => 'colors',
					'label'       => esc_html__( 'Header Background Color', 'neovantage' ),
					'description' => esc_html__( 'Select color for header background.', 'neovantage' ),
				)
			)
		);

		$all_font_names = array(
			1 => esc_html__( 'Font 1', 'neovantage' ),
			2 => esc_html__( 'Font 2', 'neovantage' ),
		);

		/**
		 * Font Combination 1.
		 */
		$wp_customize->add_setting(
			'neovantage_font_combination_title_1',
			array(
				'default'           => 1,
				'transport'         => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage_font_combination_title_1',
				array(
					'settings' => 'neovantage_font_combination_title_1',
					'section'  => 'typography',
					'label'    => esc_html__( 'Font Combination 1', 'neovantage' ),
					'choices'  => 'top',
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_source',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);
		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_font_combination_1_source',
				array(
					'settings' => 'neovantage_font_combination_1_source',
					'section'  => 'typography',
					'label'    => esc_html__( 'Font Source', 'neovantage' ),
					'multi'    => 'off',
					'choices'  => array(
						1 => 'Google Fonts',
						2 => 'Typekit',
						3 => esc_attr__( 'Custom', 'neovantage' ),
					),
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_google',
			array(
				'default'           => 'Noto Sans',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_google_weight',
			array(
				'default'           => '700',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_google_subset',
			array(
				'default'           => array( 'latin' ),
				'sanitize_callback' => 'neovantage_sanitize_array',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_google_cat',
			array(
				'default'           => 'sans-serif',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Typography(
				$wp_customize,
				'neovantage_font_combination_1_google',
				array(
					'settings' => array( 'neovantage_font_combination_1_google', 'neovantage_font_combination_1_google_weight', 'neovantage_font_combination_1_google_subset', 'neovantage_font_combination_1_google_cat' ),
					'section'  => 'typography',
					'label'    => array( esc_html__( 'Google Font', 'neovantage' ), esc_html__( 'Font Weight', 'neovantage' ), esc_html__( 'Character Set', 'neovantage' ) ),
					'choices'  => neovantage_google(),
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_typekit',
			array(
				'sanitize_callback' => 'esc_attr',
			)
		);
		$wp_customize->add_control(
			'neovantage_font_combination_1_typekit',
			array(
				'settings'    => 'neovantage_font_combination_1_typekit',
				'section'     => 'typography',
				'label'       => esc_html__( 'Typekit Kit ID', 'neovantage' ),
				'description' => esc_html__( 'Log in to your Typekit account, add fonts to your kit and publish. Now copy and paste the Typekit Kit ID in the input below.', 'neovantage' ),
				'type'        => 'text',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_typekit_custom',
			array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			)
		);
		$wp_customize->add_control(
			'neovantage_font_combination_1_typekit_custom',
			array(
				'settings'    => 'neovantage_font_combination_1_typekit_custom',
				'section'     => 'typography',
				'label'       => esc_html__( 'Typekit Font Name', 'neovantage' ),
				'description' => esc_html__( 'Enter the font-family name value here. Click "Using fonts in CSS" option in Typekit editor to get correct name. Example: banshee-std', 'neovantage' ),
				'type'        => 'text',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_typekit_fallback',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);
		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_font_combination_1_typekit_fallback',
				array(
					'settings' => 'neovantage_font_combination_1_typekit_fallback',
					'section'  => 'typography',
					'label'    => esc_html__( 'Fallback', 'neovantage' ),
					'multi'    => 'off',
					'choices'  => array(
						1 => 'Sans-serif',
						2 => 'Serif',
					),
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_custom',
			array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			)
		);
		$wp_customize->add_control(
			'neovantage_font_combination_1_custom',
			array(
				'settings'    => 'neovantage_font_combination_1_custom',
				'section'     => 'typography',
				'label'       => esc_html__( 'Custom Font Name', 'neovantage' ),
				'description' => esc_html__( 'You need to add your font via "@fontface" in the custom css option first (Tutorial: https://www.w3schools.com/cssref/css3_pr_font-face_rule.asp). Then just enter the font-family name value here. Example: Droid Serif', 'neovantage' ),
				'type'        => 'text',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_1_weight_custom',
			array(
				'default'           => '400',
				'sanitize_callback' => 'absint',
			)
		);
		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_font_combination_1_weight_custom',
				array(
					'settings' => 'neovantage_font_combination_1_weight_custom',
					'section'  => 'typography',
					'label'    => esc_html__( 'Font Weight', 'neovantage' ),
					'multi'    => 'off',
					'choices'  => neovantage_customizer_font_weights(),
				)
			)
		);

		/**
		 * Font Combination 2.
		 */
		$wp_customize->add_setting(
			'neovantage_font_combination_title_2',
			array(
				'default'           => 1,
				'transport'         => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage_font_combination_title_2',
				array(
					'settings' => 'neovantage_font_combination_title_2',
					'section'  => 'typography',
					'label'    => esc_html__( 'Font Combination 2', 'neovantage' ),
					'choices'  => 'top',
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_source',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_font_combination_2_source',
				array(
					'label'    => esc_html__( 'Font Source', 'neovantage' ),
					'section'  => 'typography',
					'settings' => 'neovantage_font_combination_2_source',
					'multi'    => 'off',
					'choices'  => array(
						1 => 'Google Fonts',
						2 => 'Typekit',
						3 => esc_attr__( 'Custom', 'neovantage' ),
					),
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_google',
			array(
				'default'           => 'Karla',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_google_weight',
			array(
				'default'           => '400',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_google_subset',
			array(
				'default'           => array( 'latin' ),
				'sanitize_callback' => 'neovantage_sanitize_array',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_google_cat',
			array(
				'default'           => 'sans-serif',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Typography(
				$wp_customize,
				'neovantage_font_combination_2_google',
				array(
					'label'    => array( esc_html__( 'Google Font', 'neovantage' ), esc_html__( 'Font Weight', 'neovantage' ), esc_html__( 'Character Set', 'neovantage' ) ),
					'section'  => 'typography',
					'settings' => array( 'neovantage_font_combination_2_google', 'neovantage_font_combination_2_google_weight', 'neovantage_font_combination_2_google_subset', 'neovantage_font_combination_2_google_cat' ),
					'choices'  => neovantage_google(),
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_typekit',
			array(
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_control(
			'neovantage_font_combination_2_typekit',
			array(
				'label'       => esc_html__( 'Typekit Kit ID', 'neovantage' ),
				'description' => esc_html__( 'Log in to your Typekit account, add fonts to your kit and publish. Now copy and paste the Typekit Kit ID in the input below.', 'neovantage' ),
				'section'     => 'typography',
				'type'        => 'text',
				'settings'    => 'neovantage_font_combination_2_typekit',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_typekit_custom',
			array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_control(
			'neovantage_font_combination_2_typekit_custom',
			array(
				'label'       => esc_html__( 'Typekit Font Name', 'neovantage' ),
				'description' => esc_html__( 'Enter the font-family name value here. Click "Using fonts in CSS" option in Typekit editor to get correct name. Example: banshee-std', 'neovantage' ),
				'section'     => 'typography',
				'type'        => 'text',
				'settings'    => 'neovantage_font_combination_2_typekit_custom',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_typekit_fallback',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_font_combination_2_typekit_fallback',
				array(
					'label'    => esc_html__( 'Fallback', 'neovantage' ),
					'section'  => 'typography',
					'settings' => 'neovantage_font_combination_2_typekit_fallback',
					'multi'    => 'off',
					'choices'  => array(
						1 => 'Sans-serif',
						2 => 'Serif',
					),
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_custom',
			array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			)
		);

		$wp_customize->add_control(
			'neovantage_font_combination_2_custom',
			array(
				'label'       => esc_html__( 'Custom Font Name', 'neovantage' ),
				'description' => esc_html__( 'You need to add your font via "@fontface" in the custom css option first (Tutorial: https://www.w3schools.com/cssref/css3_pr_font-face_rule.asp). Then just enter the font-family name value here. Example: Droid Serif', 'neovantage' ),
				'section'     => 'typography',
				'type'        => 'text',
				'settings'    => 'neovantage_font_combination_2_custom',
			)
		);

		$wp_customize->add_setting(
			'neovantage_font_combination_2_weight_custom',
			array(
				'default'           => '400',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_font_combination_2_weight_custom',
				array(
					'label'    => esc_html__( 'Font Weight', 'neovantage' ),
					'section'  => 'typography',
					'settings' => 'neovantage_font_combination_2_weight_custom',
					'multi'    => 'off',
					'choices'  => neovantage_customizer_font_weights(),
				)
			)
		);

		/**
		 * Font Assigning.
		 */
		$wp_customize->add_setting(
			'_neovantage_title_header_typography_specific',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'_neovantage_title_header_typography_specific',
				array(
					'label'       => esc_html__( 'Assign Fonts', 'neovantage' ),
					'description' => esc_html__( 'Select which font each element uses', 'neovantage' ),
					'section'     => 'typography',
					'settings'    => '_neovantage_title_header_typography_specific',
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_heading_font',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_heading_font',
				array(
					'label'    => esc_html__( 'Headings', 'neovantage' ),
					'section'  => 'typography',
					'settings' => 'neovantage_heading_font',
					'multi'    => 'off',
					'choices'  => $all_font_names,
				)
			)
		);

		$wp_customize->add_setting(
			'neovantage_body_font',
			array(
				'default'           => 2,
				'transport'         => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_body_font',
				array(
					'label'    => esc_html__( 'Body', 'neovantage' ),
					'section'  => 'typography',
					'settings' => 'neovantage_body_font',
					'multi'    => 'off',
					'choices'  => $all_font_names,
				)
			)
		);
	}

	/**
	 * Register our blog controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_single_post_controls( $wp_customize ) {
		/**
		 * Get Image from Content Checkbox
		 */
		$wp_customize->add_setting(
			'neovantage_get_image_from_content',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_get_image_from_content' ),
				'sanitize_callback' => 'neovantage_sanitize_checkbox',
			)
		);
		$wp_customize->add_control(
			'neovantage_get_image_from_content',
			array(
				'settings'    => 'neovantage_get_image_from_content',
				'section'     => 'single-post',
				'label'       => esc_html__( 'Get Featured Image from Content', 'neovantage' ),
				'description' => esc_html__( 'If you have not set a Featured image allow the system to show the first image from post content on archive pages.', 'neovantage' ),
				'type'        => 'checkbox',
			)
		);

		/**
		 * Related Post Checkbox
		 */
		$wp_customize->add_setting(
			'neovantage_related_posts',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_related_posts' ),
				'sanitize_callback' => 'neovantage_sanitize_checkbox',
			)
		);
		$wp_customize->add_control(
			'neovantage_related_posts',
			array(
				'settings'    => 'neovantage_related_posts',
				'section'     => 'single-post',
				'label'       => esc_html__( 'Show Related Posts', 'neovantage' ),
				'description' => esc_html__( 'Enabling this will add related posts at the bottom of post content.', 'neovantage' ),
				'type'        => 'checkbox',
			)
		);

		/**
		 * Related Posts Count
		 */
		$wp_customize->add_setting(
			'neovantage_related_posts_count',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_related_posts_count' ),
				'sanitize_callback' => 'neovantage_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'neovantage_related_posts_count',
			array(
				'settings'    => 'neovantage_related_posts_count',
				'section'     => 'single-post',
				'label'       => esc_html__( 'Related Posts Count', 'neovantage' ),
				'description' => esc_html__( 'Enter related posts count.', 'neovantage' ),
			)
		);

		/**
		 * Related Posts Algorithm
		 */
		$wp_customize->add_setting(
			'neovantage_related_posts_algorithm',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_related_posts_algorithm' ),
				'sanitize_callback' => 'neovantage_sanitize_select',
			)
		);
		$wp_customize->add_control(
			new Neovantage_Control_Multi_Select(
				$wp_customize,
				'neovantage_related_posts_algorithm',
				array(
					'settings' => 'neovantage_related_posts_algorithm',
					'section'  => 'single-post',
					'label'    => esc_html__( 'Related Posts Algorithm', 'neovantage' ),
					'multi'    => 'off',
					'choices'  => array(
						'rand' => esc_attr__( 'by Random', 'neovantage' ),
					),
				)
			)
		);
	}

	/**
	 * Register our layout controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   2.0.0
	 */
	public function neovantage_register_layout_controls( $wp_customize ) {

		/**
		 * Sidebar Layout Title.
		 *
		 * - Setting: Sidebar Layout Title
		 * - Control: Title
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage-sidebar-layout-title',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage-sidebar-layout-title',
				array(
					'label'       => esc_html__( 'Default Sidebar Layout', 'neovantage' ),
					'description' => esc_html__( 'Choose a default page layout for your post pages: Sidebar Right, Sidebar Left or Fullwidth.', 'neovantage' ),
					'section'     => 'layout',
					'settings'    => 'neovantage-sidebar-layout-title',
					'choices'     => 'category',
				)
			)
		);

		/**
		 * Sidebar Layout.
		 *
		 * - Setting: Sidebar Layout
		 * - Control: Custom Radio Image
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage-sidebar-layout',
			array(
				'default'           => neovantage_get_default_theme_setting( 'sidebar_layout' ),
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Radio_Image(
				$wp_customize,
				'neovantage-sidebar-layout',
				array(
					'section'  => 'layout',
					'settings' => 'neovantage-sidebar-layout',
					'cols'     => 3,
					'choices'  => neovantage_customizer_sidebar_layouts(),
				)
			)
		);

		/**
		 * Page Sidebar Layout Title.
		 *
		 * - Setting: Page Sidebar Layout Title
		 * - Control: Title
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage-page-sidebar-layout-title',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage-page-sidebar-layout-title',
				array(
					'label'       => esc_html__( 'Default Page Sidebar Layout', 'neovantage' ),
					'description' => esc_html__( 'Choose a default page layout for your content pages: Sidebar Right, Sidebar Left or Fullwidth.', 'neovantage' ),
					'section'     => 'layout',
					'settings'    => 'neovantage-page-sidebar-layout-title',
					'choices'     => 'category',
				)
			)
		);

		/**
		 * Page Sidebar Layout.
		 *
		 * - Setting: Page Sidebar Layout
		 * - Control: Custom Radio Image
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage-page-sidebar-layout',
			array(
				'default'           => neovantage_get_default_theme_setting( 'page_sidebar_layout' ),
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Radio_Image(
				$wp_customize,
				'neovantage-page-sidebar-layout',
				array(
					'section'  => 'layout',
					'settings' => 'neovantage-page-sidebar-layout',
					'cols'     => 3,
					'choices'  => neovantage_customizer_sidebar_layouts(),
				)
			)
		);

		/**
		 * Category Layout Title.
		 *
		 * - Setting: Category Layout Title
		 * - Control: Title
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_category_layout_title',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage_category_layout_title',
				array(
					'label'       => esc_html__( 'Default Categories Layout', 'neovantage' ),
					'description' => esc_html__( 'Select the default layout for categories.', 'neovantage' ),
					'section'     => 'layout',
					'settings'    => 'neovantage_category_layout_title',
					'choices'     => 'category',
				)
			)
		);

		/**
		 * Category Layout.
		 *
		 * - Setting: Category Layout
		 * - Control: Custom Radio Image
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_category_layout',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Radio_Image(
				$wp_customize,
				'neovantage_category_layout',
				array(
					'section'  => 'layout',
					'settings' => 'neovantage_category_layout',
					'cols'     => 2,
					'choices'  => neovantage_customizer_layouts(),
				)
			)
		);

		/**
		 * Tag Layout Title.
		 *
		 * - Setting: Tag Layout Title
		 * - Control: Title
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_tag_layout_title',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage_tag_layout_title',
				array(
					'label'       => esc_html__( 'Default Tags Layout', 'neovantage' ),
					'description' => esc_html__( 'Select the default layout for tags.', 'neovantage' ),
					'section'     => 'layout',
					'settings'    => 'neovantage_tag_layout_title',
					'choices'     => 'tag',
				)
			)
		);

		/**
		 * Tag Layout.
		 *
		 * - Setting: tag Layout
		 * - Control: Custom Radio Image
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_tag_layout',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Radio_Image(
				$wp_customize,
				'neovantage_tag_layout',
				array(
					'section'  => 'layout',
					'settings' => 'neovantage_tag_layout',
					'cols'     => 2,
					'choices'  => neovantage_customizer_layouts(),
				)
			)
		);

		/**
		 * Author Layout Title.
		 *
		 * - Setting: Author Layout Title
		 * - Control: Title
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_author_layout_title',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage_author_layout_title',
				array(
					'label'       => esc_html__( 'Default Author Layout', 'neovantage' ),
					'description' => esc_html__( 'Select the default layout for author.', 'neovantage' ),
					'section'     => 'layout',
					'settings'    => 'neovantage_author_layout_title',
					'choices'     => 'author',
				)
			)
		);

		/**
		 * Author Layout.
		 *
		 * - Setting: Author Layout
		 * - Control: Custom Radio Image
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_author_layout',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Radio_Image(
				$wp_customize,
				'neovantage_author_layout',
				array(
					'section'  => 'layout',
					'settings' => 'neovantage_author_layout',
					'cols'     => 2,
					'choices'  => neovantage_customizer_layouts(),
				)
			)
		);

		/**
		 * Search Page Layout Title.
		 *
		 * - Setting: Search Page Layout Title
		 * - Control: Title
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_search_page_layout_title',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Title(
				$wp_customize,
				'neovantage_search_page_layout_title',
				array(
					'label'       => esc_html__( 'Default Search Page Layout', 'neovantage' ),
					'description' => esc_html__( 'Select the default layout for search page.', 'neovantage' ),
					'section'     => 'layout',
					'settings'    => 'neovantage_search_page_layout_title',
					'choices'     => 'author',
				)
			)
		);

		/**
		 * Search Page Layout.
		 *
		 * - Setting: Search Page Layout
		 * - Control: Custom Radio Image
		 * - Sanitization: absint
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_search_page_layout',
			array(
				'default'           => 1,
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Control_Radio_Image(
				$wp_customize,
				'neovantage_search_page_layout',
				array(
					'section'  => 'layout',
					'settings' => 'neovantage_search_page_layout',
					'cols'     => 2,
					'choices'  => neovantage_customizer_layouts(),
				)
			)
		);
	}

	/**
	 * Register our footer controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_footer_controls( $wp_customize ) {
		/**
		 * Footer Widgets Area setting.
		 *
		 * - Setting: Footer Widgets Area
		 * - Control: checkbox
		 * - Sanitization: checkbox
		 *
		 * Uses a checkbox to enable/disable the Footer Widgets Area.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'footer_widget_area_setting',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'footer_widget_area_setting' ),
				'type'              => 'theme_mod',
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'neovantage_sanitize_checkbox',
			)
		);

		/**
		 * Basic Checkbox control.
		 *
		 * - Control: Checkbox
		 * - Setting: Footer Widgets Area
		 * - Sanitization: checkbox
		 *
		 * Register the core "checkbox" control to be used to enable/disable Footer Widgets Area setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'footer_widget_area_control',
			array( // $args
				'settings'    => 'footer_widget_area_setting',
				'section'     => 'footer',
				'label'       => esc_html__( 'Footer Widgets Area', 'neovantage' ),
				'description' => esc_html__( 'Enable/Disable the Footer Widgets area globally. Please visit Appearance/Widgets menu to add new widgets!', 'neovantage' ),
				'type'        => 'checkbox',
			)
		);

		/**
		 * Footer Copyright Text setting example.
		 *
		 * - Setting: Footer Copyright Text
		 * - Control: textarea
		 * - Sanitization: html
		 *
		 * Uses a text field to configure the user's copyright text displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'footer_copyright_text',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'footer_copyright_text' ),
				'type'              => 'theme_mod',
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'neovantage_sanitize_html',
			)
		);

		/**
		 * Basic Text control.
		 *
		 * - Control: Basic: textarea
		 * - Setting: Footer Copyright Text
		 * - Sanitization: html
		 *
		 * Register the core "text" control to be used to configure the Footer Copyright Text setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'footer_copyright_text',
			array( // $args
				'settings'    => 'footer_copyright_text',
				'section'     => 'footer',
				'label'       => esc_html__( 'Footer Copyright Text', 'neovantage' ),
				'description' => esc_html__( 'Copyright or other text to be displayed in the site footer. HTML allowed.', 'neovantage' ),
				'type'        => 'textarea',
			)
		);
	}

	/**
	 * Register our social media controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_social_media_controls( $wp_customize ) {
		/**
		 * Facebook Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Facebook Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'facebook_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'facebook_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Facebook Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the Facebook Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'facebook_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'Facebook', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);

		/**
		 * Twitter Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Twitter Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'twitter_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'twitter_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Twitter Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the Twitter Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'twitter_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'Twitter', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);

		/**
		 * Google+ Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Google+ Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'google_plus_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'google_plus_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Google+ Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the Google+ Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'google_plus_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'Google+', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);

		/**
		 * Instagram Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Instagram Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'instagram_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'instagram_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Instagram Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the Instagram Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'instagram_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'Instagram', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);

		/**
		 * LinkedIn Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: LinkedIn Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'linkedIn_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'linkedIn_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: LinkedIn Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the LinkedIn Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'linkedIn_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'LinkedIn', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);

		/**
		 * Pinterest Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Pinterest Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'pinterest_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'pinterest_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: Pinterest Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the Pinterest Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'pinterest_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'Pinterest', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);

		/**
		 * StumbleUpon Follow Link Setting
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: StumbleUpon Follow Link
		 * - Sanitization: URL
		 *
		 * Uses a URL text field to configure the company social link URL displayed in the site footer.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'stumbleupon_link',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'stumbleupon_link' ),
				'sanitize_callback' => 'neovantage_sanitize_url',
			)
		);

		/**
		 * Basic URL control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Social Media Section
		 * - Setting: StumbleUpon Follow Link
		 * - Control: URL
		 *
		 * Register the core "URL" text control to be used to configure the StumbleUpon Link setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'stumbleupon_link',
			array( // $args
				'section'     => 'social-media',
				'label'       => esc_html__( 'StumbleUpon', 'neovantage' ),
				'description' => esc_html__( 'Follow link URL to be displayed in the site footer.', 'neovantage' ),
				'type'        => 'url',
			)
		);
	}

	/**
	 * Register our notice bar & GDPR controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_notice_bar_gdpr_controls( $wp_customize ) {
		/**
		 * Notice Bar
		 */
		$wp_customize->add_setting(
			'neovantage_notifications',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications' ),
				'sanitize_callback' => 'neovantage_switch_sanitization',
			)
		);

		$wp_customize->add_control(
			new Neovantage_Customize_Switch_Control(
				$wp_customize,
				'neovantage_notifications',
				array(
					'label'    => esc_html__( 'Show Notifications', 'neovantage' ),
					'section'  => 'notice-bar-gdpr',
					'priority' => 0,
				)
			)
		);

		/**
		 * Notification Text
		 */
		$wp_customize->add_setting(
			'neovantage_notifications_text',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications_text' ),
				'sanitize_callback' => 'neovantage_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'neovantage_notifications_text',
			array(
				'priority'    => 2,
				'section'     => 'notice-bar-gdpr',
				'label'       => esc_html__( 'Notification Text', 'neovantage' ),
				'description' => esc_html__( 'The default text to indicate that your site uses cookies', 'neovantage' ),
			)
		);

		/**
		 * More Info Text
		 */
		$wp_customize->add_setting(
			'neovantage_notifications_more_info_text',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications_more_info_text' ),
				'sanitize_callback' => 'neovantage_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'neovantage_notifications_more_info_text',
			array(
				'priority'    => 4,
				'section'     => 'notice-bar-gdpr',
				'label'       => esc_html__( 'More Info Text', 'neovantage' ),
				'description' => esc_html__( 'The default text to use to link to a page providing further information', 'neovantage' ),
			)
		);
		/**
		 * More Info Page
		 */
		$wp_customize->add_setting(
			'neovantage_notifications_more_info_page',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications_more_info_page' ),
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control(
			'neovantage_notifications_more_info_page',
			array(
				'priority'    => 6,
				'section'     => 'notice-bar-gdpr',
				'type'        => 'dropdown-pages',
				'label'       => esc_html__( 'More Info Page', 'neovantage' ),
				'description' => esc_html__( 'The page containing further information about your cookie policy.', 'neovantage' ),
			)
		);

		/**
		 * Accept Text
		 */
		$wp_customize->add_setting(
			'neovantage_notifications_accept_button_text',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications_accept_button_text' ),
				'sanitize_callback' => 'neovantage_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'neovantage_notifications_accept_button_text',
			array(
				'priority'    => 8,
				'section'     => 'notice-bar-gdpr',
				'label'       => esc_html__( 'Accept Text', 'neovantage' ),
				'description' => esc_html__( 'The default text to dismiss the notification', 'neovantage' ),
			)
		);

		/**
		 * Cookie Expiry
		 */
		$wp_customize->add_setting(
			'neovantage_notifications_cookie_expiry',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications_cookie_expiry' ),
				'sanitize_callback' => 'absint',
			)
		);
		$wp_customize->add_control(
			'neovantage_notifications_cookie_expiry',
			array(
				'priority'    => 8,
				'section'     => 'notice-bar-gdpr',
				'label'       => esc_html__( 'Cookie Expiry', 'neovantage' ),
				'description' => esc_html__( 'The number of days that the cookie is set for', 'neovantage' ),
			)
		);

		/**
		 * Cookie Version
		 */
		$wp_customize->add_setting(
			'neovantage_notifications_cookie_version',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_notifications_cookie_version' ),
				'sanitize_callback' => 'absint',
			)
		);
		$wp_customize->add_control(
			'neovantage_notifications_cookie_version',
			array(
				'priority'    => 8,
				'section'     => 'notice-bar-gdpr',
				'label'       => esc_html__( 'Cookie Version', 'neovantage' ),
				'description' => esc_html__( 'The number of days that the cookie is set for', 'neovantage' ),
			)
		);
	}

	/**
	 * Register our site loader controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_site_loader_controls( $wp_customize ) {

		/**
		 * Preloader setting.
		 *
		 * - Setting: Preloader
		 * - Control: select
		 * - Sanitization: select
		 *
		 * Uses a dropdown select to enable/disable the preloader.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'preloader',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'preloader' ),
				'type'              => 'theme_mod',
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'neovantage_sanitize_select',
			)
		);

		/**
		 * Basic Select control.
		 *
		 * - Control: Select
		 * - Setting: Preloader
		 * - Sanitization: select
		 *
		 * Register the core "select" control to be used to enable/disable the Preloader setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'preloader',
			array( // $args
				'settings'    => 'preloader',
				'section'     => 'site-loader',
				'type'        => 'select',
				'label'       => esc_html__( 'Preloader', 'neovantage' ),
				'description' => esc_html__( 'Select enable to be used the preloader feature for your site.', 'neovantage' ),
				'choices'     => array(
					'enable'  => esc_html__( 'Enable', 'neovantage' ),
					'disable' => esc_html__( 'Disable', 'neovantage' ),
				),
			)
		);
	}

	/**
	 * Register our maintenance mode controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   2.0.0
	 */
	public function neovantage_register_maintenance_mode_controls( $wp_customize ) {
		/**
		 * Maintenance Mode setting.
		 *
		 * - Setting: Maintenance Mode
		 * - Control: custom switch control
		 * - Sanitization: switch
		 *
		 * Uses a switch to enable/disable the maintenance mode.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_maintenance_mode_setting',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_maintenance_mode_setting' ),
				'sanitize_callback' => 'neovantage_switch_sanitization',
			)
		);

		/**
		 * Custom Switch Control.
		 *
		 * - Control: Switch
		 * - Setting: Enable/Disable Maintenance Mode
		 * - Sanitization: switch
		 *
		 * Register the custom control "switch" control to be used to enable/disbale Maintenance Mode setting.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			new Neovantage_Customize_Switch_Control(
				$wp_customize,
				'neovantage_maintenance_mode_setting',
				array(
					'priority'    => 0,
					'section'     => 'maintenance-mode',
					'label'       => esc_html__( 'Enable Maintenance Mode', 'neovantage' ),
					'description' => esc_html__( 'Site visitors will see a site logo with the message you set below.', 'neovantage' ),
				)
			)
		);

		/**
		 * Maintenance Message setting.
		 *
		 * - Setting: Maintenance Message
		 * - Control: textarea
		 * - Sanitization: html
		 *
		 * Uses a textarea to configure the Maintenance Message for the Theme.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_maintenance_msg_setting',
			array( // $args
				'default'           => neovantage_get_default_theme_setting( 'neovantage_maintenance_msg_setting' ),
				'sanitize_callback' => 'neovantage_sanitize_html',
				'transport'         => 'postMessage',
			)
		);

		/**
		 * Basic Textarea control.
		 *
		 * - Control: Textarea
		 * - Setting: Maintenance Message
		 * - Sanitization: html
		 *
		 * Register the core "textarea" control to be used to configure the Maintenance Message for the Theme.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'neovantage_maintenance_msg_setting',
			array( // $args
				'settings'    => 'neovantage_maintenance_msg_setting',
				'section'     => 'maintenance-mode',
				'type'        => 'textarea',
				'label'       => esc_html__( 'Maintenance Message', 'neovantage' ),
				'description' => esc_html__( 'Message to show in maintenance mode', 'neovantage' ),
			)
		);
	}

	/**
	 * Register our custom HTML code controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	public function neovantage_register_custom_html_code_controls( $wp_customize ) {
		/**
		 * Codes Between <head> and </head> Tags Settings
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes Between <head> and </head> Tags
		 * - Sanitization: html
		 *
		 * Uses a textarea to configure the Head Tag Code for the Theme.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_code_head',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_code_head' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'neovantage_sanitize_none',
			)
		);

		/**
		 * Basic Textarea control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes Between <head> and </head> Tags
		 * - Control: textarea
		 *
		 * Register the core "textarea" control to be used to configure the Code Tag for the Theme.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'neovantage_code_head',
			array( // $args
				'section'     => 'custom-html-code',
				'label'       => esc_html__( 'Codes between <head> and </head> tags', 'neovantage' ),
				'description' => esc_html__( 'Please be careful. Bad codes can make invalidation issue.', 'neovantage' ),
				'type'        => 'textarea',
			)
		);

		/**
		 * Codes right after <body> tag Settings
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes right after <body> tag
		 * - Sanitization: html
		 *
		 * Uses a textarea to configure the right after Body Tag Code for the Theme.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_code_body_start',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_code_body_start' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'neovantage_sanitize_none',
			)
		);

		/**
		 * Basic Textarea control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes right after <body> tag
		 * - Control: textarea
		 *
		 * Register the core "textarea" control to be used to configure the Code Tag after body tag for the Theme.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'neovantage_code_body_start',
			array( // $args
				'section'     => 'custom-html-code',
				'label'       => esc_html__( 'Codes right after <body> tag', 'neovantage' ),
				'description' => esc_html__( 'Please be careful. Bad codes can make invalidation issue.', 'neovantage' ),
				'type'        => 'textarea',
			)
		);

		/**
		 * Codes right before </body> tag Settings
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes right before </body> tag
		 * - Sanitization: html
		 *
		 * Uses a textarea to configure the right after Body Tag Code for the Theme.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_code_body_end',
			array(
				'default'           => neovantage_get_default_theme_setting( 'neovantage_code_body_end' ),
				'transport'         => 'postMessage',
				'sanitize_callback' => 'neovantage_sanitize_none',
			)
		);

		/**
		 * Basic Textarea control.
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes right before </body> tag
		 * - Control: textarea
		 *
		 * Register the core "textarea" control to be used to configure the Code Tag after body tag for the Theme.
		 *
		 * @uses $wp_customize->add_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_control/
		 * @link $wp_customize->add_control() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_control
		 */
		$wp_customize->add_control(
			'neovantage_code_body_end',
			array( // $args
				'section'     => 'custom-html-code',
				'label'       => esc_html__( 'Codes right before </body> tag', 'neovantage' ),
				'description' => esc_html__( 'Please be careful. Bad codes can make invalidation issue.', 'neovantage' ),
				'type'        => 'textarea',
			)
		);
	}

	/**
	 * Export/Import our customizer options controls
	 *
	 * @access  public
	 * @param   WP_Customize_Manager $wp_customize WP_Customize_Manager instance.
	 * @version 1.0.0
	 *
	 * @since   2.0.0
	 */
	public function neovantage_register_export_import_controls( $wp_customize ) {

		/**
		 * Codes Between <head> and </head> Tags Settings
		 *
		 * - Panel: NEOVANTAGE Theme Options Panel
		 * - Section: Add Custom HTML Code Section
		 * - Setting: Codes Between <head> and </head> Tags
		 * - Sanitization: html
		 *
		 * Uses a textarea to configure the Head Tag Code for the Theme.
		 *
		 * @uses $wp_customize->add_setting() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_setting/
		 * @link $wp_customize->add_setting() https://codex.wordpress.org/Class_Reference/WP_Customize_Manager/add_setting
		 */
		$wp_customize->add_setting(
			'neovantage_export_import',
			array(
				'default'           => '',
				'type'              => 'none',
				'sanitize_callback' => 'neovantage_sanitize_none',
			)
		);

		/**
		 * Custom Export/Import Control.
		 *
		 * - Section: Export/Import Section
		 * - Control: Custom Export/Import Control
		 */
		$wp_customize->add_control(
			new Neovantage_Control_Export_Import(
				$wp_customize,
				'neovantage_export_import',
				array(
					'section'       => 'neovantage-export-import',
					'label_1'       => esc_html__( 'Export', 'neovantage' ),
					'description_1' => esc_html__( 'Click the button below to export the customization settings for this theme.', 'neovantage' ),
					'label_2'       => esc_html__( 'Import', 'neovantage' ),
					'description_2' => esc_html__( 'Upload a file to import customization settings for this theme.', 'neovantage' ),
				)
			)
		);
	}
}

$neovantage_settings = new Neovantage_Initialise_Customizer_Settings();
