<?php
/**
 * NEOVANTAGE control multi select class
 *
 * @package NEOVANTAGE
 *
 * @since 2.0.0
 * @author Mohsin Rafique <https://pixelspress.com>
 */
class Neovantage_Control_Multi_Select extends WP_Customize_Control {

	/**
	 * Control type
	 *
	 * @since  2.0.0
	 */
	public $type  = 'neovantage-multi-select';
	public $multi = 'on';

	/**
	 * Enqueue control related scripts
	 *
	 * @since 2.0.0
	 */
	public function enqueue() {

		wp_enqueue_script( 'searchable-option-list', get_template_directory_uri() . '/js/admin/searchable-option-list.js', array( 'jquery' ), '2.0.2', true );
		wp_enqueue_script( 'neovantage-control-multi-select', get_template_directory_uri() . '/js/admin/neovantage-control-multi-select.js', array( 'jquery', 'searchable-option-list' ), '1.0.0', true );
	}

	/**
	 * Render content of the control
	 *
	 * @since 2.0.0
	 */
	public function render_content() {
		$multi      = ( 'off' == $this->multi ) ? false : true;
		$wrap_class = 'neovantage-select-wrap';
		if ( ! empty( $multi ) ) {
			$wrap_class .= ' neovantage-select-wrap-multi';
		}
		?>
	<label class="control-vertical-c">
		<?php
		if ( ! empty( $this->label ) ) {
			echo '<span class="customize-control-title">' . esc_attr( $this->label );
			if ( ! empty( $this->description ) ) {
				echo '<span class="tipi-tip description customize-control-description dashicons dashicons-editor-help" data-title="' . esc_attr( $this->description ) . '"></span>';
			}
			echo '</span>';
		}
		?>
		<div class="<?php echo esc_attr( $wrap_class ); ?>">
			<select
			<?php
			if ( ! empty( $multi ) ) {
				?>
				 multiple="multiple" <?php } ?> <?php $this->link(); ?> name="_customize-neovantage-multi-select-<?php echo esc_attr( $this->id ); ?>">
				<?php
				foreach ( $this->choices as $key => $value ) {
					echo '<option value="' . esc_attr( $key ) . '"';
					if ( ! empty( $multi ) ) {
						if ( is_array( $this->value() ) && in_array( $key, $this->value() ) ) {
							echo 'selected="selected"';
						}
					} else {
						if ( $key == $this->value() ) {
							echo 'selected="selected"';
						}
					}
					echo '>' . esc_attr( $value ) . '</option>';
				}
				?>
			</select>
		</div>
	</label>
		<?php
	}
}
