<?php
/**
 * NEOVANTAGE control radio image class
 *
 * @package NEOVANTAGE
 * @since 2.0.0
 *
 * @author Mohsin Rafique <https://pixelspress.com>
 */
class Neovantage_Control_Radio_Image extends WP_Customize_Control {

	/**
	 * Control type
	 *
	 * @since  1.0.0
	 */
	public $type = 'neovantage-radio-image';

	public $cols = 4;

	/**
	 * Enqueue control related scripts
	 *
	 * @since 1.0.0
	 */
	public function enqueue() {

		wp_enqueue_script( 'neovantage-control-radio-image', get_template_directory_uri() . '/js/admin/neovantage-control-radio-image.js', array( 'jquery' ), false, true );

	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 *
	 * @since 1.0.0
	 */
	public function to_json() {

		parent::to_json();

		// Sanitize URLs.
		foreach ( $this->choices as $key => $value ) {
			$this->choices[ $key ]['url'] = esc_url( $value['url'] );
			$this->choices[ $key ]['url'] = rtrim( $this->choices[ $key ]['url'], '/' );
			$ext                          = substr( $this->choices[ $key ]['url'], -3 );

			if ( 'png' == $ext ) {
				$retina                          = substr_replace( $value['url'], '@2x', -4, 0 );
				$this->choices[ $key ]['retina'] = esc_url( $retina );
			}
		}

		$this->json['choices'] = $this->choices;
		$this->json['link']    = $this->get_link();
		$this->json['value']   = $this->value();
		$this->json['id']      = $this->id;
		$this->json['cols']    = $this->cols;
	}

	/**
	 * Render a JS template for the content of the control
	 *
	 * @since 1.0.0
	 */
	public function content_template() {
		?>
		<span class="neovantage-control neovantage-radio-image-wrap neovantage-cf">
			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}<# if ( data.description ) { #>
				<span class="tipi-tip description customize-control-description dashicons dashicons-editor-help" data-title="{{{ data.description }}}"></span>
			<# } #></span>
			<# } #>

			<span class="neovantage-radio-images neovantage-columns-{{ data.cols }}">
				<# for ( key in data.choices ) { #>
					<span class="neovantage-radio-image neovantage-radio-image-{{ key }}">
						<input type="radio" id="{{ data.id }}-{{ key }}" value="{{ key }}" <# if ( (data.value) == (key) ) { #>checked="checked"<# } #> name="_customize-neovantage-radio-image-{{ data.id }}" {{{ data.link }}}>
						<label for="{{ data.id }}-{{ key }}">
							<img src="{{ data.choices[ key ][ 'url' ] }}" <# if ( data.choices[ key ][ 'retina' ] ) { #>srcset="{{ data.choices[ key ][ 'retina' ] }} 2x"<# } #> >
						</label>
					</span>
				<# } #>
			</span>
		</span>
		<?php
	}
}
