<?php
if ( ! function_exists( 'neovantage_customizer_hidden_attr' ) ) :
	/**
	 * Helper for Customizer Preview
	 *
	 * @param   $theme_mod
	 *
	 * @version 1.0.0
	 * @since   1.2.6
	 */
	function neovantage_customizer_hidden_attr( $theme_mod ) {
		if ( is_customize_preview() && ! get_theme_mod( $theme_mod, false ) ) {
			echo ' style="display:none"';
		}
	}
endif;

if ( ! function_exists( 'neovantage_enqueue_customizer_stylesheet' ) ) :
	/**
	 * Add Custom CSS to Customizer
	 */
	function neovantage_enqueue_customizer_stylesheet() {
		$theme   = wp_get_theme( get_template() );
		$version = $theme['Version'];

		wp_enqueue_style( 'neovantage-customizer-admin', get_template_directory_uri() . '/css/admin-customizer.css', null, $version, 'all' );
	}
endif;
add_action( 'customize_controls_print_styles', 'neovantage_enqueue_customizer_stylesheet' );

/**
 * Styles
 *
 * @since  1.0.0
 */
function neovantage_customizer_controls() {
	$theme   = wp_get_theme( get_template() );
	$version = $theme['Version'];

	wp_enqueue_script( 'neovantage-admin-custom', get_template_directory_uri() . '/js/admin/neovantage-custom-cb.js', array( 'jquery', 'customize-preview' ), $version, true );

	// Localize.
	wp_localize_script(
		'neovantage-admin-custom',
		'NEIl10n',
		array(
			'emptyImport' => __( 'Please choose a file to import.', 'neovantage' ),
		)
	);

	$url = '';
	wp_localize_script(
		'neovantage-admin-custom',
		'neovantageObj',
		array(
			'url'           => $url,
			'check'         => esc_html__( 'This action cannot be undone. Are you sure you want to reset all your Theme Options settings?', 'neovantage' ),
			'root'          => esc_url_raw( rest_url() ) . 'pixelspress-neovantage/v2/',
			'nonce'         => wp_create_nonce( 'wp_rest' ),
			'customizerURL' => admin_url( 'customize.php' ),
			'exportNonce'   => wp_create_nonce( 'nei-exporting' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'neovantage_customizer_controls' );

/**
 * Get Font Weights
 *
 * @since  1.0.0
 */
function neovantage_customizer_font_weights( $args = array() ) {
	$weights = array(
		'100'       => 'Thin (100)',
		'100italic' => 'Thin Italic (100)',
		'200'       => 'Extra-light (200)',
		'200italic' => 'Extra-light Italic (200)',
		'300'       => 'Light (300)',
		'300italic' => 'Light Italic (300)',
		'400'       => 'Regular (400)',
		'400italic' => 'Regular Italic (400)',
		'500'       => 'Medium (500)',
		'500italic' => 'Medium Italic (500)',
		'600'       => 'Semi-bold (600)',
		'600italic' => 'Semi-bold Italic (600)',
		'700'       => 'Bold (700)',
		'700italic' => 'Bold Italic (700)',
		'800'       => 'Extra-bold (800)',
		'800italic' => 'Extra-bold Italic (800)',
		'900'       => 'Black (900)',
		'900italic' => 'Black Italic (900)',
	);

	if ( ! empty( $args ) ) {
		$weights = array_merge( $args, $weights );
	}

	return $weights;
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function neovantage_customize_preview_js() {
	wp_enqueue_script( 'neovantage_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'neovantage_customize_preview_js' );

if ( ! function_exists( 'neovantage_is_customize_preview' ) ) {
	/**
	 * Handy function customizer preview state for current page
	 *
	 * @version 1.0.0
	 * @since   1.2.6
	 *
	 * @return bool
	 */
	function neovantage_is_customize_preview() {

		static $is_customizer;

		if ( is_null( $is_customizer ) ) {
			$is_customizer = is_customize_preview();
		}

		return $is_customizer;
	}
}

/**
 * Get Layouts List
 *
 * @param boolean $src_uri
 * @param arary   $output
 *
 * @since  2.0.0
 *
 * @return arary
 */
function neovantage_customizer_layouts( $src_uri = true, $output = array() ) {

	$src_uri = true == $src_uri ? get_template_directory_uri() . '/images/admin/' : '';

	$output[1] = array( 'url' => esc_url( $src_uri ) . 'layout-1.png' );
	$output[2] = array( 'url' => esc_url( $src_uri ) . 'layout-2.png' );

	foreach ( $output as $key => $value ) {
		$value['url']             = rtrim( $value['url'], '/' );
		$ext                      = substr( $value['url'], -3 );
		$retina                   = 'png' == $ext ? substr_replace( $value['url'], '@2x', -4, 0 ) : '';
		$output[ $key ]['srcset'] = $retina;
	}

	return $output;
}

/**
 * Get Sidebar Layouts List
 *
 * @param boolean $src_uri
 * @param arary   $output
 *
 * @since  2.0.0
 *
 * @return array
 */
function neovantage_customizer_sidebar_layouts( $src_uri = true, $output = array() ) {

	$src_uri = true == $src_uri ? get_template_directory_uri() . '/images/admin/' : '';

	$output[1] = array( 'url' => esc_url( $src_uri ) . 'layout-sidebar-1.png' );
	$output[2] = array( 'url' => esc_url( $src_uri ) . 'layout-sidebar-2.png' );
	$output[3] = array( 'url' => esc_url( $src_uri ) . 'layout-sidebar-3.png' );

	foreach ( $output as $key => $value ) {
		$value['url']             = rtrim( $value['url'], '/' );
		$ext                      = substr( $value['url'], -3 );
		$retina                   = 'png' == $ext ? substr_replace( $value['url'], '@2x', -4, 0 ) : '';
		$output[ $key ]['srcset'] = $retina;
	}

	return $output;
}
