<?php
/**
 * Custom Nav Menu function that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package NEOVANTAGE
 */

/**
 * Override the primary menu.
 *
 * @param string $nav_menu The HTML content for the navigation menu.
 * @param array  $args     Array of wp_nav_menu() arguments.
 *
 * @return string $nav_menu
 */
function neovantage_menu_added_div( $nav_menu, $args ) {

	if ( 'mobile' === $args->theme_location ) {
		$type = 'login';
		if ( is_user_logged_in() ) {
			$type = 'profile';
		} elseif ( get_option( 'users_can_register' ) ) {
			$type = 'login-register';
		}

		if ( 'login' === $type ) {
			$text = __( 'Sign in', 'neovantage' );
		} elseif ( 'profile' === $type ) {
			$text = __( 'Profile', 'neovantage' );
		} elseif ( 'login-register' === $type ) {
			$text = __( 'Sign in / Join', 'neovantage' );
		} else {
			$text = '';
		}

		$user_login_item = '<a href="javascript:void(0);" class="user-login">';
		if ( 'profile' === $type ) {
			$current_user     = wp_get_current_user();
			$user_login_item .= ' <span class="user-avatar user-avatar-image">' . get_avatar( $current_user->ID, 26 ) . '</span>';
		} else {
			$user_login_item .= ' <span class="user-avatar user-avatar-icon"><i class="icon lynny-general-user-1"></i></span>';
		}
			$user_login_item .= $text;
		$user_login_item     .= '</a>';

		$close_item = '<a href="javascript:void(0);" class="neovantage-mobile-menu-close"><i class="icon lynny-general-close"></i></a>';

		$nav_menu = '<div class="mobile-navigation-header"><div class="container clearfix">
                        ' . $close_item . '
					</div></div>' . $nav_menu;
	}

	return $nav_menu;

}
add_filter( 'wp_nav_menu', 'neovantage_menu_added_div', PHP_INT_MAX, 2 );

// add_filter( 'wp_nav_menu_objects', 'neo_menu_children' );.
if ( ! class_exists( 'Neovantage_Walker_Nav_Menu_Main' ) ) :

	class Neovantage_Walker_Nav_Menu_Main extends Walker_Nav_Menu {

		/**
		 * Starts the list before the elements are added.
		 *
		 * @since 3.0.0
		 *
		 * @see Walker::start_lvl()
		 *
		 * @param string   $output Used to append additional content (passed by reference).
		 * @param int      $depth  Depth of menu item. Used for padding.
		 * @param stdClass $args   An object of wp_nav_menu() arguments.
		 */
		public function start_lvl( &$output, $depth = 0, $args = array() ) {

			if ( $depth > 3 ) {
				return;
			}
			if ( 2 === $depth ) {
				$output .= '<ul class="great-grandchild-menu">';
			}
			if ( 1 === $depth ) {
				$output .= '<ul class="grandchild-menu">';
			}
			if ( 0 === $depth ) {
				$output .= '<ul class="sub-menu">';
			}
		}

		/**
		 * Ends the list of after the elements are added.
		 *
		 * @since 3.0.0
		 *
		 * @see Walker::end_lvl()
		 *
		 * @param string   $output Used to append additional content (passed by reference).
		 * @param int      $depth  Depth of menu item. Used for padding.
		 * @param stdClass $args   An object of wp_nav_menu() arguments.
		 */
		public function end_lvl( &$output, $depth = 0, $args = array() ) {

			if ( $depth > 3 ) {
				return;
			}
			if ( 0 === $depth ) {
				$output .= '</ul>';
			}
			if ( 1 === $depth ) {
				$output .= '</ul>';
			}
			if ( 2 === $depth ) {
				$output .= '</ul>';
			}
		}
	}

endif;

if ( ! class_exists( 'Neovantage_Walker_Nav_Menu_Mobile' ) ) :

	class Neovantage_Walker_Nav_Menu_Mobile extends Walker_Nav_Menu {

		/**
		 * Starts the list before the elements are added.
		 *
		 * @since 3.0.0
		 *
		 * @see Walker::start_lvl()
		 *
		 * @param string   $output Used to append additional content (passed by reference).
		 * @param int      $depth  Depth of menu item. Used for padding.
		 * @param stdClass $args   An object of wp_nav_menu() arguments.
		 */
		public function start_lvl( &$output, $depth = 0, $args = array() ) {
			$indent = str_repeat( "\t", $depth );
			if ( $depth > 3 ) {
				return;
			}
			if ( 2 === $depth ) {
				$output .= "\n$indent<ul class=\"great-grand-sub-menu\">";
			}
			if ( 1 === $depth ) {
				$output .= "\n$indent<ul class=\"grand-sub-menu\">";
			}
			if ( 0 === $depth ) {
				$output .= "\n$indent<ul class=\"sub-menu\">";
			}
		}

		/**
		 * Starts the element output.
		 *
		 * @since 3.0.0
		 * @since 4.4.0 The {@see 'nav_menu_item_args'} filter was added.
		 *
		 * @see Walker::start_el()
		 *
		 * @param string   $output Used to append additional content (passed by reference).
		 * @param WP_Post  $object   Menu item data object.
		 * @param int      $depth  Depth of menu item. Used for padding.
		 * @param stdClass $args   An object of wp_nav_menu() arguments.
		 * @param int      $id     Current item ID.
		 */
		public function start_el( &$output, $object, $depth = 0, $args = array(), $id = 0 ) {
			$indent    = ( $depth ) ? str_repeat( "\t", $depth ) : '';
			$classes   = empty( $object->classes ) ? array() : (array) $object->classes;
			$classes[] = 'menu-item-' . $object->ID;

			/**
			 * Filter the CSS class(es) applied to a menu item's <li>.
			 *
			 * @since 3.0.0
			 *
			 * @see wp_nav_menu()
			 *
			 * @param array  $classes The CSS classes that are applied to the menu item's <li>.
			 * @param object $item    The current menu item.
			 * @param array  $args    An array of wp_nav_menu() arguments.
			 */
			$class_names = join( ' ', (array) apply_filters( 'nav_menu_css_class', array_filter( $classes ), $object, $args ) );
			$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

			/**
			 * Filter the ID applied to a menu item's <li>.
			 *
			 * @since 3.0.1
			 *
			 * @see wp_nav_menu()
			 *
			 * @param string $menu_id The ID that is applied to the menu item's <li>.
			 * @param object $object    The current menu item.
			 * @param array  $args    An array of wp_nav_menu() arguments.
			 */
			$id             = apply_filters( 'nav_menu_item_id', 'menu-item-' . $object->ID, $object, $args );
			$id             = ( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';
			$output        .= $indent . '<li' . $id . $class_names . '>';
			$atts           = array();
			$atts['title']  = ! empty( $object->attr_title ) ? $object->attr_title : '';
			$atts['target'] = ! empty( $object->target ) ? $object->target : '';
			$atts['rel']    = ! empty( $object->xfn ) ? $object->xfn : '';
			$atts['href']   = ! empty( $object->url ) ? $object->url : '';

			/**
			 * Filter the HTML attributes applied to a menu item's <a>.
			 *
			 * @since 3.6.0
			 *
			 * @see wp_nav_menu()
			 *
			 * @param array $atts {
			 *     The HTML attributes applied to the menu item's <a>, empty strings are ignored.
			 *
			 *     @type string $title  Title attribute.
			 *     @type string $target Target attribute.
			 *     @type string $rel    The rel attribute.
			 *     @type string $href   The href attribute.
			 * }
			 * @param object $item The current menu item.
			 * @param array  $args An array of wp_nav_menu() arguments.
			 */
			$atts       = apply_filters( 'nav_menu_link_attributes', $atts, $object, $args );
			$attributes = '';
			foreach ( $atts as $attr => $value ) {
				if ( ! empty( $value ) ) {
					$value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
					$attributes .= ' ' . $attr . '="' . $value . '"';
				}
			}

			$item_output      = $args->before;
			$item_output     .= '<div class="container">';
				$item_output .= '<a' . $attributes . '>';
				$item_output .= $args->link_before . apply_filters( 'the_title', $object->title, $object->ID ) . $args->link_after;
				$item_output .= '</a>';
			if ( in_array( 'menu-item-has-children', $classes ) ) {
				$item_output .= '<i class="icon lynny-arrow-down-2"></i>';
			}
			$item_output .= '</div>';
			$item_output .= $args->after;
			$output      .= apply_filters( 'walker_nav_menu_start_el', $item_output, $object, $depth, $args );
		}

		/**
		 * Ends the list of after the elements are added.
		 *
		 * @since 3.0.0
		 *
		 * @see Walker::end_lvl()
		 *
		 * @param string   $output Used to append additional content (passed by reference).
		 * @param int      $depth  Depth of menu item. Used for padding.
		 * @param stdClass $args   An object of wp_nav_menu() arguments.
		 */
		public function end_lvl( &$output, $depth = 0, $args = array() ) {
			$indent = str_repeat( "\t", $depth );

			if ( $depth > 3 ) {
				return;
			}
			if ( 0 === $depth ) {
				$output .= "$indent</ul>\n";
			}
			if ( 1 === $depth ) {
				$output .= "$indent</ul>\n";
			}
			if ( 2 === $depth ) {
				$output .= "$indent</ul>\n";
			}
		}
	}
endif;
