<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package NEOVANTAGE
 */

if ( ! function_exists( 'neovantage_entry_meta_categories' ) ) :
	/**
	 * Prints HTML with meta information for the current post i.e. categories.
	 *
	 * @global object $post Global post object.
	 *
	 * @return void
	 */
	function neovantage_entry_meta_categories() {

		// Hide categories text for pages.
		if ( 'post' === get_post_type() ) {
			$meta_html = '<ul class="entry-categories">';

			$categories_list = get_the_category_list( ' ' );
			if ( $categories_list && neovantage_categorized_blog() ) {
				$meta_html .= sprintf(
					/* translators: %1$s: Category List. */
					'<li>%1$s</li>',
					$categories_list
				); // WPCS: XSS OK.
			}

			$meta_html .= '</ul>';

			echo $meta_html; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}
endif;

if ( ! function_exists( 'neovantage_entry_meta' ) ) :
	/**
	 * Prints HTML with meta information for the current post i.e. date/time, author, post views and comments.
	 *
	 * @global object $post Global post object.
	 *
	 * @return void
	 */
	function neovantage_entry_meta() {

		if ( 'post' === get_post_type() ) :
			global $post;
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s" style="display: none;">%4$s</time>';
			}

			$time_string = sprintf(
				$time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);

			$posted_on = sprintf(
				/* translators: %s: Post Date. */
				esc_html_x( '%s', 'Post Date', 'neovantage' ),
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);

			$byline = sprintf(
				/* translators: %s: Post Author. */
				esc_html_x( '%s', 'post author', 'neovantage' ),
				'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);

			$meta_html          = '<div class="entry-meta clearfix">';
				$meta_html     .= '<ul class="meta-post">';
					$meta_html .= '<li><i class="icon lynny-general-calendar"></i> ' . $posted_on . '</li>';
					$meta_html .= '<li><i class="icon lynny-general-user-1"></i> ' . $byline . '</li>';

			if ( ! function_exists( 'is_plugin_active' ) ) {
				/**
				 * Detect plugin. For use on Front End only.
				 */
				include_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
				$meta_html .= '<li><i class="icon lynny-general-comment"></i> ';
				$meta_html .= '<a href="' . esc_url( get_comments_link( $post->ID ) ) . '">';
				$meta_html .= number_format_i18n( get_comments_number() );
				$meta_html .= '</a>';
				$meta_html .= '</li>';
			}

			if ( is_plugin_active( 'neovantage-core/neovantage-core.php' ) ) {
				if ( is_single() && class_exists( 'Neovantage_Core_Post_View_Count' ) ) :
					$post_view_count = new Neovantage_Core_Post_View_Count();
					$post_views      = $post_view_count->neovantage_get_post_views( $post->ID );
					$meta_html      .= sprintf(
						/* translators: %1$s: Post Views. */
						'<li><span class="post-views"><i class="icon lynny-general-view"></i> %1$s</span></li>',
						$post_views
					); // WPCS: XSS OK.
				endif;
			}
				$meta_html .= '</ul>';

			if ( ! is_single() && ! is_archive() ) :
				$meta_html     .= '<a href="' . esc_url( get_the_permalink() ) . '" rel="bookmark">';
					$meta_html .= sprintf(
						wp_kses(
							/* translators: %s: Name of current post. */
							__( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'neovantage' ),
							array( 'span' => array( 'class' => array() ) )
						),
						the_title( '<span class="screen-reader-text">"', '"</span>', false )
					);
				$meta_html .= '</a>';
				endif;
			$meta_html .= '</div><!-- .entry-meta -->';

			echo $meta_html;  // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		endif;
	}
endif;

if ( ! function_exists( 'neovantage_entry_meta_related_post' ) ) :
	/**
	 * Prints HTML with meta information for the current post i.e. date/timeand comments.
	 *
	 * @global object $post Global post object.
	 *
	 * @return void
	 */
	function neovantage_entry_meta_related_post() {

		if ( 'post' === get_post_type() ) :
			global $post;
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s" style="display: none;">%4$s</time>';
			}

			$time_string = sprintf(
				$time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);

			$posted_on = sprintf(
				/* translators: %s: Post Date. */
				esc_html_x( '%s', 'post date', 'neovantage' ),
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);

			$byline = sprintf(
				/* translators: %s: Post Author. */
				esc_html_x( '%s', 'post author', 'neovantage' ),
				'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);

			$meta_html          = '<div class="entry-meta clearfix">';
				$meta_html     .= '<ul class="meta-post">';
					$meta_html .= '<li><i class="icon lynny-general-calendar"></i> ' . $posted_on . '</li>';

			if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
				$meta_html .= '<li><i class="icon lynny-general-comment"></i> ';
				$meta_html .= '<a href="' . esc_url( get_comments_link( $post->ID ) ) . '">';
				$meta_html .= number_format_i18n( get_comments_number() );
				$meta_html .= '</a>';
				$meta_html .= '</li>';
			}
				$meta_html .= '</ul>';
			$meta_html     .= '</div><!-- .entry-meta -->';

			echo $meta_html; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		endif;
	}
endif;

if ( ! function_exists( 'neovantage_entry_footer' ) ) :

	/**
	 * Prints HTML with meta information for the tags.
	 */
	function neovantage_entry_footer() {

		// Hide tag text for pages.
		if ( is_single() && 'post' === get_post_type() ) {

			echo '<div class="entry-terms">';

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list();
			if ( $tags_list ) {
				printf(
					/* translators: %s: List of tags. */
					'<div class="tags-links"><i class="icon lynny-general-tags"></i> %s</div>',
					$tags_list // phpcs:ignore WordPress.Security.EscapeOutput
				);
			}

			echo '</div><!-- .entry-terms -->';
		}
	}
endif;

if ( ! function_exists( 'neovantage_edit_post' ) ) :

	/**
	 * Show edit link.
	 */
	function neovantage_edit_post() {
		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'neovantage' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}

endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function neovantage_categorized_blog() {
	$all_the_cool_cats = get_transient( 'neovantage_categories' );
	if ( false === $all_the_cool_cats ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories(
			array(
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			)
		);

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'neovantage_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so neovantage_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so neovantage_categorized_blog should return false.
		return false;
	}
}

if ( ! function_exists( 'neovantage_breadcrumbs' ) ) :

	/**
	 * Breadcrumbs
	 *
	 * @param string $align Used to align breadcrumb left or right.
	 * @global object $wp_query The WordPress Query class.
	 * @global object $post Global post object.
	 * @global object $author
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function neovantage_breadcrumbs( $align = 'left' ) {
		global $wp_query, $post;
		$item_position = 0;
		$item_position++;

		/* === OPTIONS === */
		$text['home']     = '<i class="icon lynny-general-home"></i><span itemprop="name">' . __( 'Home', 'neovantage' ) . '</span><meta itemprop="position" content="' . absint( $item_position ) . '">'; // text for the 'Home' link.
		$text['category'] = '%s'; // text for a category page.
		$text['search']   = '%s'; // text for a search results page.
		$text['tag']      = '%s'; // text for a tag page.
		$text['author']   = '%s'; // text for an author page.
		$text['404']      = __( 'Error 404', 'neovantage' ); // text for the 404 page.

		$show_current = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show.
		$show_on_home = 1; // 1 - show breadcrumbs on the homepage, 0 - don't show.
		$delimiter    = ''; // delimiter between crumbs.
		$before       = '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem" class="active">'; // Tag before the current crumb.
		$after        = '</li>'; // Tag after the current crumb.
		/* === END OF OPTIONS === */

		// $current_page = '<a title="' . esc_attr( get_the_title() ) . '" href="' . esc_url( get_permalink() ) . '">' . esc_attr( get_the_title() ) . '</a>';
		$current_page = '<span itemprop="name">' . esc_attr( get_the_title() ) . '</span>';
		$home_link    = esc_attr( home_url() ) . '/';
		$link_before  = '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
		$link_after   = '</li>';
		$link_attr    = 'itemprop="item"';
		$link         = $link_before . '<a ' . $link_attr . ' href="%1$s">%2$s</a>' . $link_after;
		$linkhome     = $link_before . '<a ' . $link_attr . ' href="%1$s" rel="home">%2$s</a>' . $link_after;

		echo '<nav role="navigation" aria-label="Breadcrumbs">';
			echo '<div class="container">';
		if ( is_front_page() ) {
			if ( 1 === $show_on_home ) {
				echo '<ul class="breadcrumb pull-right" itemscope itemtype="http://schema.org/BreadcrumbList">' . $before . '<a href="' . $home_link . '">' . $text['home'] . '</a>' . $after . '</ul>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		} else {
			echo '<ul class="breadcrumb ' . sanitize_html_class( $align ) . '" itemscope itemtype="http://schema.org/BreadcrumbList">' . sprintf( $linkhome, $home_link, $text['home'] ) . $delimiter; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			if ( is_home() ) {
				echo $before . __( 'Blog', 'neovantage' ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_category() ) {
				$this_cat = get_category( get_query_var( 'cat' ), false );
				if ( 0 !== $this_cat->parent ) {
					$cats = get_category_parents( $this_cat->parent, true, $delimiter );
					$cats = str_replace( '">', '">', $cats );
					$cats = str_replace( '<a', $link_before . '<a' . $link_attr, $cats );
					$cats = str_replace( '</a>', '</a>' . $link_after, $cats );
					echo $cats; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}
				echo $before . sprintf( $text['category'], single_cat_title( '', false ) ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_search() ) {
				echo $before . sprintf( $text['search'], get_search_query() ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_day() ) {
				echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) ) . $delimiter; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo sprintf( $link, get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ), get_the_time( 'F' ) ) . $delimiter; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo $before . get_the_time( 'd' ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_month() ) {
				echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) ) . $delimiter; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo $before . get_the_time( 'F' ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_year() ) {
				echo $before . get_the_time( 'Y' ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_single() && ! is_attachment() ) {
				if ( 'post' !== get_post_type() ) {
					$post_type = get_post_type_object( get_post_type() );
					$slug      = $post_type->rewrite;
					printf( $link, $home_link . $slug['slug'] . '/', $post_type->labels->name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					if ( 1 === $show_current ) {
						echo $delimiter . $before . $current_page . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
				} else {
					$cat = get_the_category();
					$cat = $cat[0];

					$cats = get_category_parents( $cat, true, $delimiter );

					if ( 0 === $show_current ) {
						$cats = preg_replace( "#^(.+)$delimiter$#", '$1', $cats );
					}

					$cats = str_replace( '">', '">', $cats );
					$cats = str_replace( '<a', $link_before . '<a' . $link_attr, $cats );
					$cats = str_replace( '</a>', '</a>' . $link_after, $cats );
					echo $cats; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					if ( 1 === $show_current ) {
						echo $before . $current_page . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
				}
			} elseif ( ! is_single() && ! is_page() && '' !== get_post_type() && 'post' !== get_post_type() && 'events' !== get_post_type() && ! is_404() ) {
				$post_type = get_post_type_object( get_post_type() );
				echo $before . $post_type->labels->name . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( isset( $wp_query->query_vars['taxonomy'] ) && ! empty( $wp_query->query_vars['taxonomy'] ) ) {
				$taxonomy          = '';
				$taxonomy_category = '';
				$taxonomy          = $wp_query->query_vars['taxonomy'];
				echo $before . $wp_query->query_vars[ $taxonomy ] . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_page() && ! $post->post_parent ) {
				if ( 1 === $show_current ) {
					echo $before . '<a href="' . esc_url( get_permalink() ) . '">' . esc_attr( get_the_title() ) . '</a>' . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}
			} elseif ( is_page() && $post->post_parent ) {
				$parent_id   = $post->post_parent;
				$breadcrumbs = array();
				while ( $parent_id ) {
					$page          = get_page( $parent_id );
					$breadcrumbs[] = sprintf( $link, esc_url( get_permalink( $page->ID ) ), esc_attr( get_the_title( $page->ID ) ) );
					$parent_id     = $page->post_parent;
				}
				$breadcrumbs         = array_reverse( $breadcrumbs );
				$breadcrumbs_counter = count( $breadcrumbs );
				for ( $i = 0; $i < $breadcrumbs_counter; $i++ ) {
					echo $breadcrumbs[ $i ]; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					if ( $i !== $breadcrumbs_counter - 1 ) {
						echo $delimiter; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
				}

				if ( 1 === $show_current ) {
					echo $delimiter . $before . esc_attr( get_the_title() ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}
			} elseif ( is_tag() ) {
				echo $before . sprintf( $text['tag'], esc_attr( single_tag_title( '', false ) ) ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_author() ) {
				global $author;
				$userdata = get_userdata( $author );
				echo $before . sprintf( $text['author'], esc_attr( $userdata->display_name ) ) . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			} elseif ( is_404() ) {
				echo $before . $text['404'] . $after; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
			echo '</ul>';
		}
			echo '</div>';
		echo '</nav>';
	}

endif;

if ( ! function_exists( 'get_gallery_attachments' ) ) :
	/**
	 * Get Gallery Attachment IDs
	 *
	 * @global object $post
	 * @return array
	 */
	function get_gallery_attachments() {
		global $post;

		$post_content = $post->post_content;
		preg_match( '/\[gallery.*ids=.(.*).\]/', $post_content, $ids );
		$images_id = explode( ',', $ids[1] );

		return $images_id;
	}

endif;

if ( ! function_exists( 'neovantage_grab_ids_from_gallery' ) ) :

	/**
	 * Post gallery
	 *
	 * @global object $post
	 * @return object
	 */
	function neovantage_grab_ids_from_gallery() {
		global $post;
		$gallery = neovantage_get_shortcode_from_content( 'gallery' );

		$object          = new stdClass();
		$object->columns = '3';
		$object->link    = 'post';
		$object->ids     = array();
		if ( $gallery ) {
			$object = neovantage_extra_shortcode( 'gallery', $gallery, $object );
		}
		return $object;
	}

endif;

if ( ! function_exists( 'neovantage_get_shortcode_from_content' ) ) :

	/**
	 * Get Shortcode From Content
	 *
	 * @global object $post Post Object.
	 * @param mixed $param Mix Array.
	 *
	 * @return string
	 */
	function neovantage_get_shortcode_from_content( $param ) {
		global $post;
		$pattern = get_shortcode_regex();

		$content = $post->post_content;
		if ( preg_match_all( '/' . $pattern . '/s', $content, $matches ) && array_key_exists( 2, $matches ) && in_array( $param, $matches[2] ) ) {
			$key = array_search( $param, $matches[2] );
			return $matches[0][ $key ];
		}
	}

endif;

if ( ! function_exists( 'neovantage_extra_shortcode' ) ) :

	/**
	 * Extra shortcode
	 *
	 * @param string $name Shortcode Name.
	 * @param string $shortcode Actual Shortcode.
	 * @param object $object
	 *
	 * @return object
	 */
	function neovantage_extra_shortcode( $name, $shortcode, $object ) {
		if ( $shortcode && is_object( $object ) ) {
			$attrs = str_replace( array( '[', ']', '"', $name ), 'null', $shortcode );
			$attrs = explode( ' ', $attrs );

			if ( is_array( $attrs ) ) {
				foreach ( $attrs as $attr ) {
					if ( $attr ) {
						$_attr = explode( '=', $attr );

						if ( 2 === count( $_attr ) ) {
							if ( 'ids' === $_attr[0] ) {
								$object->ids = explode( ',', $_attr[1] );
							} elseif ( 'columns' === $_attr[0] ) {
								$object->columns = $_attr[1];
							}
						}
					}
				}
			}
		}
		return $object;
	}

endif;

if ( ! function_exists( 'neovantage_social_shares' ) ) :

	/**
	 * Post Social Share Links
	 */
	function neovantage_social_shares() {
		$page_title     = get_the_title();
		$page_permalink = get_the_permalink();

		$thumbnail_id = get_post_thumbnail_id( get_the_ID() );
		$thumbnail    = wp_get_attachment_image_src( $thumbnail_id, 'large' );
		?>
		<ul class="social-share">
			<li class="share-post"><i class="icon lynny-share"></i> <?php esc_attr_e( 'Share', 'neovantage' ); ?></li>
			<li class="facebook">
				<a href="https://www.facebook.com/sharer.php?u=<?php echo esc_url( $page_permalink ); ?>" target="_blank">
					<i class="icon lynny-web-facebook"></i>
				</a>
			</li>
			<li class="twitter">
				<a href="https://twitter.com/share?text=<?php echo esc_attr( $page_title ) . '&url=' . esc_url( $page_permalink ); ?>" target="_blank">
					<i class="icon lynny-web-twitter"></i>
				</a>
			</li>
			<li class="linkedin">
				<a href="https://www.linkedin.com/shareArticle?mini=true&url=<?php echo esc_url( $page_permalink ); ?>&title=<?php echo esc_attr( $page_title ); ?>" target="_blank">
					<i class="icon lynny-web-linkedin"></i>
				</a>
			</li>
		</ul>
		<?php
	}

endif;

if ( ! function_exists( 'neovantage_site_logo' ) ) :

	/**
	 * Displays the optional custom logo.
	 *
	 * Does nothing if the custom logo is not available.
	 *
	 * @since NEOVANTAGE 1.0.4
	 */
	function neovantage_site_logo() {
		if ( function_exists( 'the_custom_logo' ) ) {
			the_custom_logo();
		}
	}
endif;

if ( ! function_exists( 'neovantage_get_brightness' ) ) :

	/**
	 * Returns brightness value from 0 to 255
	 *
	 * @param string $hex Hexa Value.
	 * @return string
	 */
	function neovantage_get_brightness( $hex ) {
		// Strip off any leading #.
		$hex = str_replace( '#', '', $hex );

		$c_r = hexdec( substr( $hex, 0, 2 ) );
		$c_g = hexdec( substr( $hex, 2, 2 ) );
		$c_b = hexdec( substr( $hex, 4, 2 ) );

		return ( ( $c_r * 299 ) + ( $c_g * 587 ) + ( $c_b * 114 ) ) / 1000;
	}
endif;

if ( ! function_exists( 'neovantage_adjust_brightness' ) ) :

	/**
	 * Adjust brightness
	 *
	 * @param string $hex
	 * @param int    $steps
	 *
	 * @return string
	 */
	function neovantage_adjust_brightness( $hex, $steps ) {
		// Steps should be between -255 and 255. Negative = darker, positive = lighter.
		$steps = max( -255, min( 255, $steps ) );

		// Format the hex color string.
		$hex = str_replace( '#', '', $hex );
		if ( 3 === strlen( $hex ) ) {
			$hex = str_repeat( substr( $hex, 0, 1 ), 2 ) . str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 );
		}

		// Get decimal values.
		$r = hexdec( substr( $hex, 0, 2 ) );
		$g = hexdec( substr( $hex, 2, 2 ) );
		$b = hexdec( substr( $hex, 4, 2 ) );

		// Adjust number of steps and keep it inside 0 to 255.
		$r = max( 0, min( 255, $r + $steps ) );
		$g = max( 0, min( 255, $g + $steps ) );
		$b = max( 0, min( 255, $b + $steps ) );

		$r_hex = str_pad( dechex( $r ), 2, '0', STR_PAD_LEFT );
		$g_hex = str_pad( dechex( $g ), 2, '0', STR_PAD_LEFT );
		$b_hex = str_pad( dechex( $b ), 2, '0', STR_PAD_LEFT );

		return '#' . $r_hex . $g_hex . $b_hex;
	}
endif;

/**
 * Get Post Format Icons
 */
function neovantage_get_post_format_icon() {
	switch ( get_post_format() ) {
		case 'gallery':
			$post_icon['icon'] = 'icon lynny-post-photo-list';
			$post_icon['text'] = __( 'GALLERY', 'neovantage' );
			break;
		case 'link':
			$post_icon['icon'] = 'icon lynny-post-link';
			$post_icon['text'] = __( 'LINK', 'neovantage' );
			break;
		case 'quote':
			$post_icon['icon'] = 'icon lynny-post-quote';
			$post_icon['text'] = __( 'QUOTE', 'neovantage' );
			break;
		case 'video':
			$post_icon['icon'] = 'icon lynny-post-video';
			$post_icon['text'] = __( 'VIDEO', 'neovantage' );
			break;
		case 'audio':
			$post_icon['icon'] = 'icon lynny-post-audio';
			$post_icon['text'] = __( 'AUDIO', 'neovantage' );
			break;
		case 'image':
			$post_icon['icon'] = 'icon lynny-post-photo';
			$post_icon['text'] = __( 'IMAGE', 'neovantage' );
			break;
		case 'status':
			$post_icon['icon'] = 'icon lynny-post-status';
			$post_icon['text'] = __( 'Status', 'neovantage' );
			break;
		case 'aside':
			$post_icon['icon'] = 'icon lynny-post-aside';
			$post_icon['text'] = __( 'Aside', 'neovantage' );
			break;
		case 'chat':
			$post_icon['icon'] = 'icon lynny-post-chat';
			$post_icon['text'] = __( 'Chat', 'neovantage' );
			break;
		default:
			if ( is_sticky() ) {
				$post_icon['icon'] = 'icon lynny-post-sticky';
				$post_icon['text'] = __( 'STICKY', 'neovantage' );
			} else {
				$post_icon['icon'] = 'icon lynny-general-file';
				$post_icon['text'] = __( 'STANDARD', 'neovantage' );
			}
			break;
	}
	return $post_icon;
}

if ( ! function_exists( 'neovantage_get_post_thumbnail' ) ) :

	/**
	 * Get the Featured image HTML of a post
	 *
	 * @param integer      $post_id Post ID.
	 * @param string       $size Thimbnauil size i.e. post-thumbnail, small, large, full.
	 * @param string|array $attr Attribute List.
	 * @param bool         $archive_only Boolean i.e. true/false.
	 * @return string
	 */
	function neovantage_get_post_thumbnail( $post_id = null, $size = 'post-thumbnail', $attr = '', $archive_only = true ) {
		$image_url = '';

		if ( has_post_thumbnail( $post_id ) ) {
			$image_url = get_the_post_thumbnail( $post_id, $size, $attr );
		}

		if ( $image_url ) {
			return $image_url;
		} else {

			if ( is_single() && true === $archive_only ) {
				return '';
			}
		}
	}
endif;

if ( ! function_exists( 'neovantage_has_post_thumbnail' ) ) :

	/**
	 * Get the Featured image HTML of a post
	 *
	 * @param global $post The Post object.
	 *
	 * @return string
	 */
	function neovantage_has_post_thumbnail() {

		global $post;
		$thumbnail      = array();
		$thumbnail_size = 'large';

		if ( has_post_thumbnail( $post->ID ) ) {
			$thumbnail_id = get_post_meta( $post->ID, '_thumbnail_id', true );

			// Get Post Layout i.e. Classic or List.
			$layout = neovantage_get_layout();
			if ( 'classic-view' === $layout ) {
				$thumbnail_size = 'blog-large';
			} elseif ( 'list-view' === $layout ) {
				$thumbnail_size = 'blog-medium';
			}

			$image_src    = wp_get_attachment_image_src( $thumbnail_id, $thumbnail_size );
			$image_srcset = wp_get_attachment_image_srcset( $thumbnail_id, $thumbnail_size );

			$thumbnail = array(
				'id'          => $thumbnail_id,
				'src'         => $image_src[0],
				'srcset'      => $image_srcset,
				'width'       => $image_src[1],
				'height'      => $image_src[2],
				'alt'         => '',
				'caption'     => '',
				'description' => '',
				'title'       => '',
				'full_image'  => neovantage_get_post_thumbnail( null, $thumbnail_size ),
			);

			$img_post = get_post( $thumbnail_id );

			if ( ! is_null( $img_post ) ) {
				$thumbnail['alt']         = get_post_meta( $thumbnail_id, '_wp_attachment_image_alt', true );
				$thumbnail['caption']     = $img_post->post_excerpt;
				$thumbnail['description'] = $img_post->post_content;
			}
		} else {
			$neovantage_get_image_from_content = neovantage_get_theme_mod( 'neovantage_get_image_from_content' );
			if ( $neovantage_get_image_from_content ) {
				$matches = array();
				$output  = preg_match_all( '|<img.*?src=[\'"](.*?)[\'"].*?>|i', $post->post_content, $matches );

				if ( isset( $matches[1][0] ) ) {
					$thumbnail = array(
						'id'          => '',
						'src'         => $matches[1][0],
						'width'       => '',
						'height'      => '',
						'alt'         => '',
						'caption'     => '',
						'description' => '',
						'title'       => '',
						'full_image'  => '<img src="' . esc_url( $matches[1][0] ) . '" alt="' . esc_attr( $post->post_title ) . '">',
					);
				}
			}
		}

		return $thumbnail;
	}
endif;

if ( ! function_exists( 'neovantage_render_preloader' ) ) :

	/**
	 * Render Preloader
	 *
	 * @since 1.1.0
	 */
	function neovantage_render_preloader() {
		$preloader_status = get_theme_mod( 'preloader', 'enable' );
		if ( isset( $preloader_status ) && 'enable' === $preloader_status ) :

			echo '<!-- It allows to create preloader -->';
			echo '<div id="preloader" class="preloader">';
				echo '<span>' . esc_html__( 'Loading', 'neovantage' ) . '</span>';
			echo '</div>';
		endif;
	}
endif;

if ( ! function_exists( 'neovantage_get_theme_mod' ) ) :

	/**
	 * Get Theme Options
	 * Returns saved value of option or default from config
	 *
	 * @param string         $name Theme modification name.
	 * @param (string|false) $check_customize_preview Theme modification default value.
	 *
	 * @version     1.0.0
	 * @since       1.2.6
	 *
	 * @return bool|string
	 */
	function neovantage_get_theme_mod( $name, $check_customize_preview = true ) {

		$result = get_theme_mod( $name, neovantage_get_default_theme_setting( $name ) );
		if ( ! $result && $check_customize_preview ) {
			$result = neovantage_is_customize_preview();
		}

		return $result;
	}
endif;

if ( ! function_exists( 'neovantage_version_check_using_wpapi' ) ) :
	/**
	 *
	 * Get Plugin Latest Version Details
	 *
	 * @since   2.0.0
	 * @param string $plugin_name The plugin name.
	 * @return object
	 */
	function neovantage_version_check_using_wpapi( $plugin_name ) {
		$response = wp_safe_remote_get( 'https://api.wordpress.org/plugins/info/1.0/' . esc_attr( $plugin_name ) . '.json' );

		// Check for error.
		if ( is_wp_error( $response ) ) {
			return;
		}

		// Parse remote HTML file.
		$data = json_decode( wp_remote_retrieve_body( $response ) );

		// Check for error.
		if ( is_wp_error( $data ) ) {
			return;
		}

		if ( ! empty( $data ) ) {
			return $data;
		}
	}
endif;

if ( ! function_exists( 'neovantage_count' ) ) :
	/**
	 * Safe count function
	 *
	 * @param (int|array) $variable Countable array/integer value.
	 * @since 2.0.0
	 *
	 * @return integer
	 */
	function neovantage_count( $variable ) {

		// PHP > 7.1.
		if ( function_exists( 'is_countable' ) && is_countable( $variable ) ) {
			return count( $variable );
		}

		// PHP < 7.2.
		if ( is_array( $variable ) ) {
			return count( $variable );
		}

		return 0;
	}
endif;

if ( ! function_exists( 'neovantage_merge_args' ) ) :
	/**
	 * Merges 2 array quickly
	 *
	 * @param array $args
	 * @param array $default
	 *
	 * @since 2.0.0
	 *
	 * @return array
	 */
	function neovantage_merge_args( $args, array $default = array() ) {

		if ( is_string( $args ) ) {
			$_args = array();
			$args  = wp_parse_str( $args, $_args );
			$args  = $_args;
		}

		if ( empty( $default ) ) {
			return $args;
		}

		foreach ( $default as $_def => $value ) {
			if ( ! isset( $args[ $_def ] ) ) {
				$args[ $_def ] = $value;
			}
		}

		return $args;
	}
endif;

if ( ! function_exists( 'neovantage_taxonomy_supports_post_type' ) ) :
	/**
	 * Checks taxonomy to make sure that was added to a post type
	 *
	 * @param object $taxonomy
	 * @param string $post_type Post Type.
	 *
	 * @return bool|mixed
	 */
	function neovantage_taxonomy_supports_post_type( $taxonomy, $post_type ) {

		static $supports;

		if ( is_null( $supports ) ) {
			$supports = array();
		}

		if ( isset( $supports[ $post_type ] ) ) {
			return $supports[ $post_type ];
		}

		global $wp_taxonomies;

		if ( empty( $wp_taxonomies[ $taxonomy ]->object_type ) ) {
			$supports[ $post_type ] = false;
			return $supports[ $post_type ];
		}

		$supports[ $post_type ] = in_array( $post_type, $wp_taxonomies[ $taxonomy ]->object_type );
		return $supports[ $post_type ];

	}
endif;

if ( ! function_exists( 'neovantage_is_valid_tax' ) ) :
	/**
	 * Handy function to detect current post is valid taxonomy for category options or not!
	 *
	 * @param string $type taxonomy type e.g. category.
	 * @param bool   $queried_object Boolean i.e. true/false.
	 *
	 * @since 2.0.0
	 * @return bool
	 */
	function neovantage_is_valid_tax( $type = 'category', $queried_object = false ) {

		static $valid;

		if ( ! is_null( $valid ) && isset( $valid[ $type ] ) ) {
			return $valid[ $type ];
		}

		if ( 'category' === $type ) {

			if ( ! $queried_object ) {
				if ( is_category() ) {
					$valid[ $type ] = true;
					return $valid[ $type ];
				} elseif ( ! is_tax() ) {
					$valid[ $type ] = false;
					return $valid[ $type ];
				}
			}
		} else {
			$valid[ $type ] = false;
			return $valid[ $type ];
		}

		$taxonomies[ $type ] = '';

		if ( ! is_object( $queried_object ) ) {
			$queried_object = get_queried_object();
		}

		if ( ! isset( $queried_object->taxonomy ) ) {
			$valid[ $type ] = false;
			return $valid[ $type ];
		}

		$valid[ $type ] = isset( $taxonomies[ $queried_object->taxonomy ] );
		return $valid[ $type ];

	}
endif;

if ( ! function_exists( 'neovantage_fonts_url' ) ) :
	/**
	 * Register custom fonts.
	 */
	function neovantage_fonts_url() {
		$fonts_url     = '';
		$font_families = array();

		/*
		 * Translators: If there are characters in your language that are not
		 * supported by Heebo, translate this to 'off'. Do not translate
		 * into your own language.
		 */
		$noto_sans = esc_html_x( 'on', 'Noto Sans font: on or off', 'neovantage' );

		/*
		 * Translators: If there are characters in your language that are not
		 * supported by Lora, translate this to 'off'. Do not translate
		 * into your own language.
		 */
		$karla = esc_html_x( 'on', 'Karla font: on or off', 'neovantage' );

		/**
		 * Get font selections from Customizer options.
		 */
		$heading = neovantage_get_theme_mod( 'neovantage_heading_font' );
		$body    = neovantage_get_theme_mod( 'neovantage_body_font' );

		// Return early if we're using system fonts.
		if ( ( 'System Fonts' === $heading || 'System Serif' === $heading ) && ( 'System Fonts' === $body || 'System Serif' === $body ) ) {
			return null;
		}

		// Heading font.
		$font_families[] = 'Noto Sans:700';

		// Body font.
		$font_families[] = 'karla:400,400i,700';

		$query_args = array(
			'family' => rawurlencode( implode( '|', array_unique( $font_families ) ) ),
			'subset' => rawurlencode( 'latin, latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );

		return esc_url_raw( $fonts_url );
	}
endif;


if ( ! function_exists( 'neovantage_user_agent' ) ) {
	/**
	 * Returns an neovantage user agent for use with premium plugin downloads.
	 *
	 * @since 2.0.0
	 * @return string
	 */
	function neovantage_user_agent() {
		return 'neovantage-user-agent';
	}
}

if ( ! function_exists( 'neovantage_get_package' ) ) :
	/**
	 * Get the download URL for a plugin.
	 *
	 * @since 2.0.0
	 * @param string       $download The plugin to download.
	 * @param string       $version The plugin version.
	 * @param string|false $token    Force-use a token, or use default if false.
	 *
	 * @return string|false
	 */
	function neovantage_get_package( $download, $version, $token = false ) {

		// Try to get a cached response.
		$download_src = get_transient( 'neovantage_remote_installer_package_' . $download );

		// If we've got it cached, then return it.
		if ( false !== $download_src ) {
			return $download_src;
		}

		$token = ( ! $token ) ? '' : $token;

		// Source is not cached, retrieve it and cache it.
		// Check for token and then install if it's valid.
		// $nonces = neovantage_get_nonce( $download, $version, $token );

		$registered = ( ! in_array( $download, array( 'NEOVANTAGE Core' ), true ) ) ? true : true;

		// if ( false !== $nonces && $registered ) {
		if ( $registered ) {

			/*
			$api_args = array(
				'neovantage_action' => 'get_download',
				'item_name'         => rawurlencode( $download ),
				'nonce'             => isset( $nonces[0] ) ? $nonces[0] : '',
				't'                 => isset( $nonces[1] ) ? $nonces[1] : '',
				'ver'               => wp_get_theme()->get( 'version' ),
			);
			$download_src = add_query_arg( $api_args, $this->api_url );
			*/
			$download_src = 'https://downloads.pixelspress.com/plugin/' . sanitize_title_with_dashes( $download ) . '.' . $version . '.zip';
			set_transient( 'neovantage_remote_installer_package_' . $download, $download_src, 300 );

			return $download_src;
		}

		// Something went wrong, return false.
		return false;
	}
endif;

if ( ! function_exists( 'neovantage_get_nonce' ) ) :

	/**
	 * Checks token against API.
	 *
	 * @access private
	 * @param string $download The name of the download.
	 * @param string $token    The token.
	 * @return false|string    Returns false if invalid.
	 *                         If valid, then returns a nonce from the remote server.
	 */
	function neovantage_get_nonce( $download, $version, $token = false ) {

		// Tweak for Envato Hosted.
		$is_pixelspress_hosted = (bool) ( defined( 'PIXELSPRESS_HOSTED_SITE' ) && PIXELSPRESS_HOSTED_SITE && defined( 'SUBSCRIPTION_CODE' ) && SUBSCRIPTION_CODE );
		$token                 = ( $is_pixelspress_hosted ) ? SUBSCRIPTION_CODE : $token;

		// Get any existing copy of our transient data.
		// $saved_nonce = get_transient( 'neovantage_ri_' . $download . $token );
		$saved_nonce = false;

		if ( false === $saved_nonce ) {

			// It wasn't there, so regenerate the data and save the transient.
			// $neovantage_version = wp_get_theme()->get( 'version' );
			// $url                = 'https://downloads.pixelspress.com?pixelspress_action=request_download&item_name=' . rawurlencode( $download ) . '&token=' . $token . '&ver=' . $neovantage_version;
			// $url               .= ( $is_pixelspress_hosted ) ? '&pixelspress-hosted=true' : '';
			$url      = 'https://downloads.pixelspress.com/plugin/' . sanitize_title_with_dashes( $download ) . '.' . $version . '.zip';
			$response = wp_remote_get( $url, array( 'user-agent' => 'pixelspress-user-agent' ) );
			$body     = wp_remote_retrieve_body( $response );

			// Check for errors.
			$error_responses = array(
				'Product not defined' => 'download-undefined',
				'Invalid Token'       => 'invalid-token',
			);
			foreach ( $error_responses as $key => $value ) {
				if ( false !== strpos( $body, $key ) ) {
					return false;
				}
			}

			/*
			$trimmed = trim( $body );
			$parts   = explode( '|', $trimmed );
			$saved_nonce = array();
			if ( 2 === count( $parts ) ) {
				$saved_nonce = array(
					esc_attr( $parts[0] ),
					esc_attr( $parts[1] ),
				);
			} else {
				return false;
			}
			*/

			set_transient( 'neovantage_ri_' . $download . $token, $saved_nonce, 600 );
		}
		return $saved_nonce;
	}
endif;

if ( ! function_exists( 'neovantage_related_posts' ) ) :

	/**
	 * Related Post
	 *
	 * @since 2.0.0
	 */
	function neovantage_related_posts() {
		global $post;
		$neovantage_post_id       = $post->ID;
		$neovantage_tag_check     = null;
		$neovantage_all_cats      = array();
		$neovantage_related_args  = null;
		$neovantage_related_posts = null;

		$neovantage_related_posts = neovantage_get_theme_mod( 'neovantage_related_posts' );
		if ( ! $neovantage_related_posts ) {
			return;
		}
		$neovantage_related_posts_amount = neovantage_get_theme_mod( 'neovantage_related_posts_count' );
		// $neovantage_related_posts_show = ot_get_option( 'neovantage_related_posts_show', 'both' );
		$neovantage_related_posts_order = neovantage_get_theme_mod( 'neovantage_related_posts_algorithm' );
		$neovantage_categories          = get_the_category( $neovantage_post_id );
		if ( ! empty( $neovantage_categories ) && ! is_wp_error( $neovantage_categories ) ) :
			foreach ( $neovantage_categories as $neovantage_category ) :
				array_push( $neovantage_all_cats, $neovantage_category->term_id );
			endforeach;
		endif;

		$neovantage_related_args  = array(
			'numberposts' => $neovantage_related_posts_amount,
			'category'    => $neovantage_all_cats,
			'exclude'     => array( $neovantage_post_id ),
			'post_status' => 'publish',
			'post_type'   => 'post',
			'orderby'     => $neovantage_related_posts_order,
		);
		$neovantage_related_posts = get_posts( $neovantage_related_args );
		if ( $neovantage_related_posts ) :
			?>
		<div class="related-post">
			<h4 class="related-post-title"><span><?php esc_html_e( 'Related Post', 'neovantage' ); ?></span></h4>
			<div class="row">
				<?php
				foreach ( $neovantage_related_posts as $post ) {
					setup_postdata( $post );
					?>
				<div class="col-sm-12 col-md-6">
					<div class="neovantage-blog-box">
						<?php get_template_part( 'template-parts/content', 'entry-media' ); ?>
						<div class="iq-blog-detail">
							<h5 class="entry-title"><a href="<?php the_permalink(); ?>"><?php echo esc_html( get_the_title() ); ?></a></h5>
							<?php neovantage_entry_meta_related_post(); ?>
							<?php the_excerpt(); ?>
							<div class="blog-button">
								<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="pull-left"><i class="icon lynny-general-user-1" aria-hidden="true"></i> <?php echo esc_html( get_the_author() ); ?></a>
								<a href="<?php the_permalink(); ?>" class="pull-right"><?php esc_html_e( 'Read More', 'neovantage' ); ?> <span class="meta-nav">&rarr;</span></a>
							</div>
						</div>
					</div>
				</div>
				<?php } wp_reset_postdata(); ?>
			</div>
		</div>
				<?php
		endif;
	}

endif;

/**
 * Comments
 */
/**
 * Check if the specified comment is written by the author of the post commented on.
 *
 * @param object $comment Comment data.
 *
 * @since 2.0.0
 *
 * @return bool
 */
function neovantage_is_comment_by_post_author( $comment = null ) {

	if ( is_object( $comment ) && $comment->user_id > 0 ) {
		$get_user = get_userdata( $comment->user_id );
		$get_post = get_post( $comment->comment_post_ID );

		if ( ! empty( $get_user ) && ! empty( $get_post ) ) {
			return $comment->user_id === $get_post->post_author;
		}
	}

	return false;
}

/**
 * Get Post Layout i.e. Classic or List
 *
 * @since 2.0.4
 *
 * @return string
 */
function neovantage_get_layout() {

	$layout = 'list-view';

	if ( is_category() ) :

		$category_layout = neovantage_get_theme_mod( 'neovantage_category_layout' );

		// Classic/List View.
		if ( 1 === $category_layout ) :
			$layout = 'classic-view';
		elseif ( 2 === $category_layout ) :
			$layout = 'list-view';
		endif;
	endif;

	if ( is_tag() ) :

		$tag_layout = neovantage_get_theme_mod( 'neovantage_tag_layout' );

		// Classic/List View.
		if ( 1 === $tag_layout ) :
			$layout = 'classic-view';
		elseif ( 2 === $tag_layout ) :
			$layout = 'list-view';
		endif;
	endif;

	if ( is_author() ) :

		$author_layout = neovantage_get_theme_mod( 'neovantage_author_layout' );

		// Classic/List View.
		if ( 1 === $author_layout ) :
			$layout = 'classic-view';
		elseif ( 2 === $author_layout ) :
			$layout = 'list-view';
		endif;
	endif;

	return $layout;
}
