<?php
/**
 * Add Typekit Support
 * See: https://typekit.com/
 *
 * @package     NEOVANTAGE
 * @link        https://pixelspress.com/theme
 */

if ( ! function_exists( 'neovantage_typekit_setup' ) ) :
	/**
	 * Enqueue Typekit scripts.
	 */
	function neovantage_typekit_setup() {

		// Get the option from the Customizer > Style > Typography section.
		$typekit_id = neovantage_get_theme_mod( 'typekit_id' );

		// Return if there's no font ID.
		if ( empty( $typekit_id ) ) {
			return;
		}

		// Enqueue the Typekit Javascript file, using the Typekit ID provided.
		wp_enqueue_script( 'neovantage-typekit', '//use.typekit.net/' . esc_js( $typekit_id ) . '.js', false, '@@pkg.version', 'all' );

		// Add the inine script.
		if ( wp_script_is( 'neovantage-typekit', 'enqueued' ) ) {
			wp_add_inline_script( 'neovantage-typekit', 'try{Typekit.load({ async: true });}catch(e){}' );
		}
	}
endif;
add_action( 'wp_head', 'neovantage_typekit_setup', 6 );
add_action( 'enqueue_block_editor_assets', 'neovantage_typekit_setup' );

/**
 * Prepends the Typekit enabled fonts added to the Customizer.
 *
 * @param  array $fonts Default fonts from the neovantage_get_fonts function.
 * @return array of default fonts, plus the new typekit additions.
 */
function neovantage_typekit_fonts( $fonts ) {

	// Get the options from the Customizer > Typography section.
	$typekit_id = neovantage_get_theme_mod( 'typekit_id' );
	$font_1     = neovantage_get_theme_mod( 'typekit_font_1' );
	$font_2     = neovantage_get_theme_mod( 'typekit_font_2' );

	// Return if there's no font family added.
	if ( empty( $typekit_id ) || ( ! $font_1 && ! $font_2 ) ) {
		return $fonts;
	}

	if ( $font_1 ) {
		// Generate the slug.
		$font_1_slug = ( $font_1 ) ? strtolower( preg_replace( '/\s+/', '-', $font_1 ) ) : null;

		// Setup the array.
		$typekit_fonts = array(
			$font_1_slug => $font_1,
		);

		// Combine arrays.
		$fonts = array_merge( $typekit_fonts, $fonts );
	}

	if ( $font_2 ) {
		// Generate the slug.
		$font_2_slug = ( $font_1 ) ? strtolower( preg_replace( '/\s+/', '-', $font_2 ) ) : null;

		// Setup the array.
		$typekit_fonts = array(
			$font_2_slug => $font_2,
		);

		// Combine arrays.
		$fonts = array_merge( $typekit_fonts, $fonts );
	}

	return $fonts;
}
add_filter( 'neovantage_fonts', 'neovantage_typekit_fonts' );
